# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

####
from Kekik.slugify         import slugify
from Kekik.unicode_tr      import unicode_tr
from Kekik.link_islemleri  import link_ayikla, youtube_link_mi
from Kekik.okunabilir_byte import okunabilir_byte
from Kekik.zaman_donustur  import sure2saniye, zaman_donustur
from Kekik.dict2json       import dict2json
# from Kekik.qr_ver          import qr_ver
# from Kekik.dosya_indir     import dosya_indir
from Kekik.hwid_kontrol    import benim_hwid, hwid_kontrol
from Kekik.txt_fetis       import satir_ekle, satirlar_ekle, satir_sil
from Kekik.list2html       import list2html
from Kekik.csv2dict        import csv2dict
from Kekik.dict2csv        import dict2csv
from Kekik.mail_gonder     import mail_gonder
from Kekik.dosya2set       import dosya2set
from Kekik.proxy_ver       import proxy_ver
# from Kekik.kisi_ver        import kisi_ver
from Kekik.Nesne           import Nesne
from Kekik.terminal_baslik import terminal_baslik
####


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from typing import List
from re     import findall, match

def link_ayikla(link:str) -> List[str]:
    """ Metindeki linkleri liste halinde return eder """
    regex = r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"

    url   = findall(regex, link)

    return [x[0] for x in url]

def youtube_link_mi(link:str) -> bool:
    return bool(match(r"http(?:s?):\/\/(?:www\.)?youtu(?:be\.com\/watch\?v=|\.be\/)([\w\-\_]*)(&(amp;)?‌​[\w\?‌​=]*)?", link))


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

# from validate_email       import validate_email
# from logging              import getLogger
# getLogger("validate_email").setLevel("ERROR")

from typing               import Union
from smtplib              import SMTP
from email.mime.multipart import MIMEMultipart
from email.mime.text      import MIMEText
from email.utils          import formataddr, formatdate, make_msgid
from pytz                 import timezone
from datetime             import datetime

def mail_gonder(
    host:str,
    port:Union[int, str],
    kullanici:str,
    sifre:str,
    gonderen_adi:str,
    gonderen_mail:str,
    alici_adi:str,
    alici_mail:str,
    konu:str,
    icerik:str,
    html:bool=False
) -> bool:
    # if not validate_email(alici_mail):
    #     return False

    mesaj = MIMEMultipart("alternative")
    mesaj["Subject"]    = konu
    mesaj["From"]       = formataddr((gonderen_adi, gonderen_mail))
    mesaj["To"]         = formataddr((alici_adi, alici_mail))
    mesaj["Message-ID"] = make_msgid(domain=gonderen_mail.split("@")[-1])  # Message-ID başlığını ekle
    # mesaj["Date"]       = formatdate(localtime=True)
    mesaj["Date"]       = datetime.now(timezone("Europe/Istanbul")).strftime("%a, %d %b %Y %H:%M:%S %z")

    mesaj.attach(MIMEText(icerik, "html") if html else MIMEText(icerik, "plain"))

    smtp = SMTP(host, int(port))
    smtp.ehlo()
    smtp.starttls()
    smtp.login(kullanici, sifre)
    smtp.sendmail(gonderen_mail, alici_mail, mesaj.as_string())
    smtp.quit()

    return True


# https://github.com/Skuzzy_xD/TelePyroBot

def sure2saniye(zaman:str) -> int:
    return sum(int(dilim) * 60 ** say for say, dilim in enumerate(reversed(zaman.split(":"))))

def zaman_donustur(saniye: int) -> str:
    dakika, saniye = divmod(saniye, 60)
    saat, dakika   = divmod(dakika, 60)
    gun, saat      = divmod(saat, 24)
    toparla = (
        (f"{round(gun)} gün, " if gun else "")
        + (f"{round(saat)} saat, " if saat else "")
        + (f"{round(dakika)} dakika, " if dakika else "")
        + (f"{round(saniye)} saniye, " if saniye else "")
    )

    return toparla[:-2]


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

# * pip3 install -U PyAudio SpeechRecognition beepy gTTS playsound pydub ffmpeg-python

from Kekik.cli          import konsol
from speech_recognition import Recognizer, Microphone, UnknownValueError, WaitTimeoutError, AudioFile
from beepy              import beep
from gtts               import gTTS
from playsound          import playsound
from os                 import system, remove
from pydub              import AudioSegment
import ffmpeg

def ses2yazi(n_saniye_dinle:int | None, bip:bool=True) -> str:
    dinleyici = Recognizer()

    import os, sys, contextlib

    @contextlib.contextmanager
    def ignore_stderr():
        devnull = os.open(os.devnull, os.O_WRONLY)
        old_stderr = os.dup(2)
        sys.stderr.flush()
        os.dup2(devnull, 2)
        os.close(devnull)
        try:
            yield
        finally:
            os.dup2(old_stderr, 2)
            os.close(old_stderr)

    with ignore_stderr() as _, Microphone() as source:
        dinleyici.adjust_for_ambient_noise(source)

        if bip:
            beep()
        konsol.log("[purple][~] Mikrofon Dinleniyor..")

        try:
            if n_saniye_dinle:
                veri = dinleyici.record(source, duration=n_saniye_dinle)
            else:
                veri = dinleyici.listen(source, timeout=5)

            yazi = dinleyici.recognize_google(veri, language="tr")

            konsol.log("[magenta][~] Ses Erişimi Tamamlandı..")
        except (UnknownValueError, WaitTimeoutError):
            yazi = ""
        except Exception as hata:
            konsol.log(f"[red][!] Hata: {type(hata).__name__}")
            yazi = ""

    return yazi

def yazi2ses(metin:str, mp3_adi:str) -> str:
    tts = gTTS(metin.strip(), lang="tr", slow=False)
    tts.save(f"{mp3_adi}.mp3")
    return f"{mp3_adi}.mp3"

def cevir(girdi_dosya:str, cikti_dosya:str) -> str:
    # system(f'ffmpeg -hide_banner -loglevel error -y -i {girdi_dosya} -af "asetrate=44100*0.9, aresample=44100, atempo=1/1.15" {cikti_dosya}')

    (
        ffmpeg
        .input(girdi_dosya, loglevel="error")
        .filter("asetrate", 44100*0.9)
        .filter("aresample", 44100)
        .filter("atempo", 1/1.15)
        .output(cikti_dosya)
        .run(overwrite_output=True)
    )

    remove(girdi_dosya)
    return cikti_dosya

def inceses(metin:str, cikti_adi:str) -> str:
    _gecici = yazi2ses(metin, "gecici")
    return cevir(_gecici, f"{cikti_adi}.mp3")


# ne_dedim = ses2yazi()
# print(ne_dedim)
# playsound(yazi2ses(ne_dedim, "dinlenen_ses"))
# playsound(inceses(ne_dedim, "dinlenen_ses"))


def dosya2yazi(dosya_yolu:str) -> None:
    gecici_dosya = "__temp.wav"

    if dosya_yolu.endswith(".mp3"):
        ses = AudioSegment.from_mp3(dosya_yolu)
    elif dosya_yolu.endswith(".wav"):
        ses = AudioSegment.from_wav(dosya_yolu)
    elif dosya_yolu.endswith(".ogg"):
        ses = AudioSegment.from_ogg(dosya_yolu)
    else:
        raise ValueError("Lütfen geçerli bir dosya uzantısı giriniz. » .mp3, .wav, .ogg")

    ses.export(gecici_dosya, format="wav")

    dinleyici = Recognizer()
    with AudioFile(gecici_dosya) as source:
        audio_data = dinleyici.record(source)
        text = dinleyici.recognize_google(audio_data, language="tr-TR")

    remove(gecici_dosya)
    return text


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

en_soyisimler = [
    "Aaron",
    "Ab",
    "Abba",
    "Abbe",
    "Abbey",
    "Abbie",
    "Abbot",
    "Abbott",
    "Abby",
    "Abdel",
    "Abdul",
    "Abe",
    "Abel",
    "Abelard",
    "Abeu",
    "Abey",
    "Abie",
    "Abner",
    "Abraham",
    "Abrahan",
    "Abram",
    "Abramo",
    "Abran",
    "Ad",
    "Adair",
    "Adam",
    "Adamo",
    "Adams",
    "Adan",
    "Addie",
    "Addison",
    "Addy",
    "Ade",
    "Adelbert",
    "Adham",
    "Adlai",
    "Adler",
    "Ado",
    "Adolf",
    "Adolph",
    "Adolphe",
    "Adolpho",
    "Adolphus",
    "Adrian",
    "Adriano",
    "Adrien",
    "Agosto",
    "Aguie",
    "Aguistin",
    "Aguste",
    "Agustin",
    "Aharon",
    "Ahmad",
    "Ahmed",
    "Ailbert",
    "Akim",
    "Aksel",
    "Al",
    "Alain",
    "Alair",
    "Alan",
    "Aland",
    "Alano",
    "Alanson",
    "Alard",
    "Alaric",
    "Alasdair",
    "Alastair",
    "Alasteir",
    "Alaster",
    "Alberik",
    "Albert",
    "Alberto",
    "Albie",
    "Albrecht",
    "Alden",
    "Aldin",
    "Aldis",
    "Aldo",
    "Aldon",
    "Aldous",
    "Aldric",
    "Aldrich",
    "Aldridge",
    "Aldus",
    "Aldwin",
    "Alec",
    "Alejandro",
    "Alejoa",
    "Aleksandr",
    "Alessandro",
    "Alex",
    "Alexander",
    "Alexandr",
    "Alexandre",
    "Alexandro",
    "Alexandros",
    "Alexei",
    "Alexio",
    "Alexis",
    "Alf",
    "Alfie",
    "Alfons",
    "Alfonse",
    "Alfonso",
    "Alford",
    "Alfred",
    "Alfredo",
    "Alfy",
    "Algernon",
    "Ali",
    "Alic",
    "Alick",
    "Alisander",
    "Alistair",
    "Alister",
    "Alix",
    "Allan",
    "Allard",
    "Allayne",
    "Allen",
    "Alley",
    "Alleyn",
    "Allie",
    "Allin",
    "Allister",
    "Allistir",
    "Allyn",
    "Aloin",
    "Alon",
    "Alonso",
    "Alonzo",
    "Aloysius",
    "Alphard",
    "Alphonse",
    "Alphonso",
    "Alric",
    "Aluin",
    "Aluino",
    "Alva",
    "Alvan",
    "Alvie",
    "Alvin",
    "Alvis",
    "Alvy",
    "Alwin",
    "Alwyn",
    "Alyosha",
    "Amble",
    "Ambros",
    "Ambrose",
    "Ambrosi",
    "Ambrosio",
    "Ambrosius",
    "Amby",
    "Amerigo",
    "Amery",
    "Amory",
    "Amos",
    "Anatol",
    "Anatole",
    "Anatollo",
    "Ancell",
    "Anders",
    "Anderson",
    "Andie",
    "Andonis",
    "Andras",
    "Andre",
    "Andrea",
    "Andreas",
    "Andrej",
    "Andres",
    "Andrew",
    "Andrey",
    "Andris",
    "Andros",
    "Andrus",
    "Andy",
    "Ange",
    "Angel",
    "Angeli",
    "Angelico",
    "Angelo",
    "Angie",
    "Angus",
    "Ansel",
    "Ansell",
    "Anselm",
    "Anson",
    "Anthony",
    "Antin",
    "Antoine",
    "Anton",
    "Antone",
    "Antoni",
    "Antonin",
    "Antonino",
    "Antonio",
    "Antonius",
    "Antons",
    "Antony",
    "Any",
    "Ara",
    "Araldo",
    "Arch",
    "Archaimbaud",
    "Archambault",
    "Archer",
    "Archibald",
    "Archibaldo",
    "Archibold",
    "Archie",
    "Archy",
    "Arel",
    "Ari",
    "Arie",
    "Ariel",
    "Arin",
    "Ario",
    "Aristotle",
    "Arlan",
    "Arlen",
    "Arley",
    "Arlin",
    "Arman",
    "Armand",
    "Armando",
    "Armin",
    "Armstrong",
    "Arnaldo",
    "Arne",
    "Arney",
    "Arni",
    "Arnie",
    "Arnold",
    "Arnoldo",
    "Arnuad",
    "Arny",
    "Aron",
    "Arri",
    "Arron",
    "Art",
    "Artair",
    "Arte",
    "Artemas",
    "Artemis",
    "Artemus",
    "Arther",
    "Arthur",
    "Artie",
    "Artur",
    "Arturo",
    "Artus",
    "Arty",
    "Arv",
    "Arvie",
    "Arvin",
    "Arvy",
    "Asa",
    "Ase",
    "Ash",
    "Ashbey",
    "Ashby",
    "Asher",
    "Ashley",
    "Ashlin",
    "Ashton",
    "Aube",
    "Auberon",
    "Aubert",
    "Aubrey",
    "Augie",
    "August",
    "Augustin",
    "Augustine",
    "Augusto",
    "Augustus",
    "Augy",
    "Aurthur",
    "Austen",
    "Austin",
    "Ave",
    "Averell",
    "Averil",
    "Averill",
    "Avery",
    "Avictor",
    "Avigdor",
    "Avram",
    "Avrom",
    "Ax",
    "Axe",
    "Axel",
    "Aylmar",
    "Aylmer",
    "Aymer",
    "Bail",
    "Bailey",
    "Bailie",
    "Baillie",
    "Baily",
    "Baird",
    "Bald",
    "Balduin",
    "Baldwin",
    "Bale",
    "Ban",
    "Bancroft",
    "Bank",
    "Banky",
    "Bar",
    "Barbabas",
    "Barclay",
    "Bard",
    "Barde",
    "Barn",
    "Barnabas",
    "Barnabe",
    "Barnaby",
    "Barnard",
    "Barnebas",
    "Barnett",
    "Barney",
    "Barnie",
    "Barny",
    "Baron",
    "Barr",
    "Barret",
    "Barrett",
    "Barri",
    "Barrie",
    "Barris",
    "Barron",
    "Barry",
    "Bart",
    "Bartel",
    "Barth",
    "Barthel",
    "Bartholemy",
    "Bartholomeo",
    "Bartholomeus",
    "Bartholomew",
    "Bartie",
    "Bartlet",
    "Bartlett",
    "Bartolemo",
    "Bartolomeo",
    "Barton",
    "Bartram",
    "Barty",
    "Bary",
    "Baryram",
    "Base",
    "Basil",
    "Basile",
    "Basilio",
    "Basilius",
    "Bastian",
    "Bastien",
    "Bat",
    "Batholomew",
    "Baudoin",
    "Bax",
    "Baxie",
    "Baxter",
    "Baxy",
    "Bay",
    "Bayard",
    "Beale",
    "Bealle",
    "Bear",
    "Bearnard",
    "Beau",
    "Beaufort",
    "Beauregard",
    "Beck",
    "Beltran",
    "Ben",
    "Bendick",
    "Bendicty",
    "Bendix",
    "Benedetto",
    "Benedick",
    "Benedict",
    "Benedicto",
    "Benedikt",
    "Bengt",
    "Beniamino",
    "Benito",
    "Benjamen",
    "Benjamin",
    "Benji",
    "Benjie",
    "Benjy",
    "Benn",
    "Bennett",
    "Bennie",
    "Benny",
    "Benoit",
    "Benson",
    "Bent",
    "Bentlee",
    "Bentley",
    "Benton",
    "Benyamin",
    "Ber",
    "Berk",
    "Berke",
    "Berkeley",
    "Berkie",
    "Berkley",
    "Berkly",
    "Berky",
    "Bern",
    "Bernard",
    "Bernardo",
    "Bernarr",
    "Berne",
    "Bernhard",
    "Bernie",
    "Berny",
    "Bert",
    "Berti",
    "Bertie",
    "Berton",
    "Bertram",
    "Bertrand",
    "Bertrando",
    "Berty",
    "Bev",
    "Bevan",
    "Bevin",
    "Bevon",
    "Bil",
    "Bill",
    "Billie",
    "Billy",
    "Bing",
    "Bink",
    "Binky",
    "Birch",
    "Birk",
    "Biron",
    "Bjorn",
    "Blaine",
    "Blair",
    "Blake",
    "Blane",
    "Blayne",
    "Bo",
    "Bob",
    "Bobbie",
    "Bobby",
    "Bogart",
    "Bogey",
    "Boigie",
    "Bond",
    "Bondie",
    "Bondon",
    "Bondy",
    "Bone",
    "Boniface",
    "Boone",
    "Boonie",
    "Boony",
    "Boot",
    "Boote",
    "Booth",
    "Boothe",
    "Bord",
    "Borden",
    "Bordie",
    "Bordy",
    "Borg",
    "Boris",
    "Bourke",
    "Bowie",
    "Boy",
    "Boyce",
    "Boycey",
    "Boycie",
    "Boyd",
    "Brad",
    "Bradan",
    "Brade",
    "Braden",
    "Bradford",
    "Bradley",
    "Bradly",
    "Bradney",
    "Brady",
    "Bram",
    "Bran",
    "Brand",
    "Branden",
    "Brander",
    "Brandon",
    "Brandtr",
    "Brandy",
    "Brandyn",
    "Brannon",
    "Brant",
    "Brantley",
    "Bren",
    "Brendan",
    "Brenden",
    "Brendin",
    "Brendis",
    "Brendon",
    "Brennan",
    "Brennen",
    "Brent",
    "Bret",
    "Brett",
    "Brew",
    "Brewer",
    "Brewster",
    "Brian",
    "Briano",
    "Briant",
    "Brice",
    "Brien",
    "Brig",
    "Brigg",
    "Briggs",
    "Brigham",
    "Brion",
    "Brit",
    "Britt",
    "Brnaba",
    "Brnaby",
    "Brock",
    "Brockie",
    "Brocky",
    "Brod",
    "Broddie",
    "Broddy",
    "Broderic",
    "Broderick",
    "Brodie",
    "Brody",
    "Brok",
    "Bron",
    "Bronnie",
    "Bronny",
    "Bronson",
    "Brook",
    "Brooke",
    "Brooks",
    "Brose",
    "Bruce",
    "Brucie",
    "Bruis",
    "Bruno",
    "Bryan",
    "Bryant",
    "Bryanty",
    "Bryce",
    "Bryn",
    "Bryon",
    "Buck",
    "Buckie",
    "Bucky",
    "Bud",
    "Budd",
    "Buddie",
    "Buddy",
    "Buiron",
    "Burch",
    "Burg",
    "Burgess",
    "Burk",
    "Burke",
    "Burl",
    "Burlie",
    "Burnaby",
    "Burnard",
    "Burr",
    "Burt",
    "Burtie",
    "Burton",
    "Burty",
    "Butch",
    "Byram",
    "Byran",
    "Byrann",
    "Byrle",
    "Byrom",
    "Byron",
    "Cad",
    "Caddric",
    "Caesar",
    "Cal",
    "Caldwell",
    "Cale",
    "Caleb",
    "Calhoun",
    "Callean",
    "Calv",
    "Calvin",
    "Cam",
    "Cameron",
    "Camey",
    "Cammy",
    "Car",
    "Carce",
    "Care",
    "Carey",
    "Carl",
    "Carleton",
    "Carlie",
    "Carlin",
    "Carling",
    "Carlo",
    "Carlos",
    "Carly",
    "Carlyle",
    "Carmine",
    "Carney",
    "Carny",
    "Carolus",
    "Carr",
    "Carrol",
    "Carroll",
    "Carson",
    "Cart",
    "Carter",
    "Carver",
    "Cary",
    "Caryl",
    "Casar",
    "Case",
    "Casey",
    "Cash",
    "Caspar",
    "Casper",
    "Cass",
    "Cassie",
    "Cassius",
    "Caz",
    "Cazzie",
    "Cchaddie",
    "Cece",
    "Cecil",
    "Cecilio",
    "Cecilius",
    "Ced",
    "Cedric",
    "Cello",
    "Cesar",
    "Cesare",
    "Cesaro",
    "Chad",
    "Chadd",
    "Chaddie",
    "Chaddy",
    "Chadwick",
    "Chaim",
    "Chalmers",
    "Chan",
    "Chance",
    "Chancey",
    "Chandler",
    "Chane",
    "Chariot",
    "Charles",
    "Charley",
    "Charlie",
    "Charlton",
    "Chas",
    "Chase",
    "Chaunce",
    "Chauncey",
    "Che",
    "Chen",
    "Ches",
    "Chester",
    "Cheston",
    "Chet",
    "Chev",
    "Chevalier",
    "Chevy",
    "Chic",
    "Chick",
    "Chickie",
    "Chicky",
    "Chico",
    "Chilton",
    "Chip",
    "Chris",
    "Chrisse",
    "Chrissie",
    "Chrissy",
    "Christian",
    "Christiano",
    "Christie",
    "Christoffer",
    "Christoforo",
    "Christoper",
    "Christoph",
    "Christophe",
    "Christopher",
    "Christophorus",
    "Christos",
    "Christy",
    "Chrisy",
    "Chrotoem",
    "Chucho",
    "Chuck",
    "Cirillo",
    "Cirilo",
    "Ciro",
    "Claiborn",
    "Claiborne",
    "Clair",
    "Claire",
    "Clarance",
    "Clare",
    "Clarence",
    "Clark",
    "Clarke",
    "Claudell",
    "Claudian",
    "Claudianus",
    "Claudio",
    "Claudius",
    "Claus",
    "Clay",
    "Clayborn",
    "Clayborne",
    "Claybourne",
    "Clayson",
    "Clayton",
    "Cleavland",
    "Clem",
    "Clemens",
    "Clement",
    "Clemente",
    "Clementius",
    "Clemmie",
    "Clemmy",
    "Cleon",
    "Clerc",
    "Cletis",
    "Cletus",
    "Cleve",
    "Cleveland",
    "Clevey",
    "Clevie",
    "Cliff",
    "Clifford",
    "Clim",
    "Clint",
    "Clive",
    "Cly",
    "Clyde",
    "Clyve",
    "Clywd",
    "Cob",
    "Cobb",
    "Cobbie",
    "Cobby",
    "Codi",
    "Codie",
    "Cody",
    "Cointon",
    "Colan",
    "Colas",
    "Colby",
    "Cole",
    "Coleman",
    "Colet",
    "Colin",
    "Collin",
    "Colman",
    "Colver",
    "Con",
    "Conan",
    "Conant",
    "Conn",
    "Conney",
    "Connie",
    "Connor",
    "Conny",
    "Conrad",
    "Conrade",
    "Conrado",
    "Conroy",
    "Consalve",
    "Constantin",
    "Constantine",
    "Constantino",
    "Conway",
    "Coop",
    "Cooper",
    "Corbet",
    "Corbett",
    "Corbie",
    "Corbin",
    "Corby",
    "Cord",
    "Cordell",
    "Cordie",
    "Cordy",
    "Corey",
    "Cori",
    "Cornall",
    "Cornelius",
    "Cornell",
    "Corney",
    "Cornie",
    "Corny",
    "Correy",
    "Corrie",
    "Cort",
    "Cortie",
    "Corty",
    "Cory",
    "Cos",
    "Cosimo",
    "Cosme",
    "Cosmo",
    "Costa",
    "Court",
    "Courtnay",
    "Courtney",
    "Cozmo",
    "Craggie",
    "Craggy",
    "Craig",
    "Crawford",
    "Creigh",
    "Creight",
    "Creighton",
    "Crichton",
    "Cris",
    "Cristian",
    "Cristiano",
    "Cristobal",
    "Crosby",
    "Cross",
    "Cull",
    "Cullan",
    "Cullen",
    "Culley",
    "Cullie",
    "Cullin",
    "Cully",
    "Culver",
    "Curcio",
    "Curr",
    "Curran",
    "Currey",
    "Currie",
    "Curry",
    "Curt",
    "Curtice",
    "Curtis",
    "Cy",
    "Cyril",
    "Cyrill",
    "Cyrille",
    "Cyrillus",
    "Cyrus",
    "D'Arcy",
    "Dael",
    "Dag",
    "Dagny",
    "Dal",
    "Dale",
    "Dalis",
    "Dall",
    "Dallas",
    "Dalli",
    "Dallis",
    "Dallon",
    "Dalston",
    "Dalt",
    "Dalton",
    "Dame",
    "Damian",
    "Damiano",
    "Damien",
    "Damon",
    "Dan",
    "Dana",
    "Dane",
    "Dani",
    "Danie",
    "Daniel",
    "Dannel",
    "Dannie",
    "Danny",
    "Dante",
    "Danya",
    "Dar",
    "Darb",
    "Darbee",
    "Darby",
    "Darcy",
    "Dare",
    "Daren",
    "Darill",
    "Darin",
    "Dario",
    "Darius",
    "Darn",
    "Darnall",
    "Darnell",
    "Daron",
    "Darrel",
    "Darrell",
    "Darren",
    "Darrick",
    "Darrin",
    "Darryl",
    "Darwin",
    "Daryl",
    "Daryle",
    "Dav",
    "Dave",
    "Daven",
    "Davey",
    "David",
    "Davidde",
    "Davide",
    "Davidson",
    "Davie",
    "Davin",
    "Davis",
    "Davon",
    "Davy",
    "De Witt",
    "Dean",
    "Deane",
    "Decca",
    "Deck",
    "Del",
    "Delainey",
    "Delaney",
    "Delano",
    "Delbert",
    "Dell",
    "Delmar",
    "Delmer",
    "Delmor",
    "Delmore",
    "Demetre",
    "Demetri",
    "Demetris",
    "Demetrius",
    "Demott",
    "Den",
    "Dene",
    "Denis",
    "Dennet",
    "Denney",
    "Dennie",
    "Dennis",
    "Dennison",
    "Denny",
    "Denver",
    "Denys",
    "Der",
    "Derby",
    "Derek",
    "Derick",
    "Derk",
    "Dermot",
    "Derrek",
    "Derrick",
    "Derrik",
    "Derril",
    "Derron",
    "Derry",
    "Derward",
    "Derwin",
    "Des",
    "Desi",
    "Desmond",
    "Desmund",
    "Dev",
    "Devin",
    "Devland",
    "Devlen",
    "Devlin",
    "Devy",
    "Dew",
    "Dewain",
    "Dewey",
    "Dewie",
    "Dewitt",
    "Dex",
    "Dexter",
    "Diarmid",
    "Dick",
    "Dickie",
    "Dicky",
    "Diego",
    "Dieter",
    "Dietrich",
    "Dilan",
    "Dill",
    "Dillie",
    "Dillon",
    "Dilly",
    "Dimitri",
    "Dimitry",
    "Dino",
    "Dion",
    "Dionisio",
    "Dionysus",
    "Dirk",
    "Dmitri",
    "Dolf",
    "Dolph",
    "Dom",
    "Domenic",
    "Domenico",
    "Domingo",
    "Dominic",
    "Dominick",
    "Dominik",
    "Dominique",
    "Don",
    "Donal",
    "Donall",
    "Donalt",
    "Donaugh",
    "Donavon",
    "Donn",
    "Donnell",
    "Donnie",
    "Donny",
    "Donovan",
    "Dore",
    "Dorey",
    "Dorian",
    "Dorie",
    "Dory",
    "Doug",
    "Dougie",
    "Douglas",
    "Douglass",
    "Dougy",
    "Dov",
    "Doy",
    "Doyle",
    "Drake",
    "Drew",
    "Dru",
    "Drud",
    "Drugi",
    "Duane",
    "Dud",
    "Dudley",
    "Duff",
    "Duffie",
    "Duffy",
    "Dugald",
    "Duke",
    "Dukey",
    "Dukie",
    "Duky",
    "Dun",
    "Dunc",
    "Duncan",
    "Dunn",
    "Dunstan",
    "Dur",
    "Durand",
    "Durant",
    "Durante",
    "Durward",
    "Dwain",
    "Dwayne",
    "Dwight",
    "Dylan",
    "Eadmund",
    "Eal",
    "Eamon",
    "Earl",
    "Earle",
    "Earlie",
    "Early",
    "Earvin",
    "Eb",
    "Eben",
    "Ebeneser",
    "Ebenezer",
    "Eberhard",
    "Eberto",
    "Ed",
    "Edan",
    "Edd",
    "Eddie",
    "Eddy",
    "Edgar",
    "Edgard",
    "Edgardo",
    "Edik",
    "Edlin",
    "Edmon",
    "Edmund",
    "Edouard",
    "Edsel",
    "Eduard",
    "Eduardo",
    "Eduino",
    "Edvard",
    "Edward",
    "Edwin",
    "Efrem",
    "Efren",
    "Egan",
    "Egbert",
    "Egon",
    "Egor",
    "El",
    "Elbert",
    "Elden",
    "Eldin",
    "Eldon",
    "Eldredge",
    "Eldridge",
    "Eli",
    "Elia",
    "Elias",
    "Elihu",
    "Elijah",
    "Eliot",
    "Elisha",
    "Ellary",
    "Ellerey",
    "Ellery",
    "Elliot",
    "Elliott",
    "Ellis",
    "Ellswerth",
    "Ellsworth",
    "Ellwood",
    "Elmer",
    "Elmo",
    "Elmore",
    "Elnar",
    "Elroy",
    "Elston",
    "Elsworth",
    "Elton",
    "Elvin",
    "Elvis",
    "Elvyn",
    "Elwin",
    "Elwood",
    "Elwyn",
    "Ely",
    "Em",
    "Emanuel",
    "Emanuele",
    "Emelen",
    "Emerson",
    "Emery",
    "Emile",
    "Emilio",
    "Emlen",
    "Emlyn",
    "Emmanuel",
    "Emmerich",
    "Emmery",
    "Emmet",
    "Emmett",
    "Emmit",
    "Emmott",
    "Emmy",
    "Emory",
    "Engelbert",
    "Englebert",
    "Ennis",
    "Enoch",
    "Enos",
    "Enrico",
    "Enrique",
    "Ephraim",
    "Ephrayim",
    "Ephrem",
    "Erasmus",
    "Erastus",
    "Erek",
    "Erhard",
    "Erhart",
    "Eric",
    "Erich",
    "Erick",
    "Erie",
    "Erik",
    "Erin",
    "Erl",
    "Ermanno",
    "Ermin",
    "Ernest",
    "Ernesto",
    "Ernestus",
    "Ernie",
    "Ernst",
    "Erny",
    "Errick",
    "Errol",
    "Erroll",
    "Erskine",
    "Erv",
    "ErvIn",
    "Erwin",
    "Esdras",
    "Esme",
    "Esra",
    "Esteban",
    "Estevan",
    "Etan",
    "Ethan",
    "Ethe",
    "Ethelbert",
    "Ethelred",
    "Etienne",
    "Ettore",
    "Euell",
    "Eugen",
    "Eugene",
    "Eugenio",
    "Eugenius",
    "Eustace",
    "Ev",
    "Evan",
    "Evelin",
    "Evelyn",
    "Even",
    "Everard",
    "Evered",
    "Everett",
    "Evin",
    "Evyn",
    "Ewan",
    "Eward",
    "Ewart",
    "Ewell",
    "Ewen",
    "Ezechiel",
    "Ezekiel",
    "Ezequiel",
    "Eziechiele",
    "Ezra",
    "Ezri",
    "Fabe",
    "Faber",
    "Fabian",
    "Fabiano",
    "Fabien",
    "Fabio",
    "Fair",
    "Fairfax",
    "Fairleigh",
    "Fairlie",
    "Falito",
    "Falkner",
    "Far",
    "Farlay",
    "Farlee",
    "Farleigh",
    "Farley",
    "Farlie",
    "Farly",
    "Farr",
    "Farrel",
    "Farrell",
    "Farris",
    "Faulkner",
    "Fax",
    "Federico",
    "Fee",
    "Felic",
    "Felice",
    "Felicio",
    "Felike",
    "Feliks",
    "Felipe",
    "Felix",
    "Felizio",
    "Feodor",
    "Ferd",
    "Ferdie",
    "Ferdinand",
    "Ferdy",
    "Fergus",
    "Ferguson",
    "Fernando",
    "Ferrel",
    "Ferrell",
    "Ferris",
    "Fidel",
    "Fidelio",
    "Fidole",
    "Field",
    "Fielding",
    "Fields",
    "Filbert",
    "Filberte",
    "Filberto",
    "Filip",
    "Filippo",
    "Filmer",
    "Filmore",
    "Fin",
    "Findlay",
    "Findley",
    "Finlay",
    "Finley",
    "Finn",
    "Fitz",
    "Fitzgerald",
    "Flem",
    "Fleming",
    "Flemming",
    "Fletch",
    "Fletcher",
    "Flin",
    "Flinn",
    "Flint",
    "Florian",
    "Flory",
    "Floyd",
    "Flynn",
    "Fons",
    "Fonsie",
    "Fonz",
    "Fonzie",
    "Forbes",
    "Ford",
    "Forest",
    "Forester",
    "Forrest",
    "Forrester",
    "Forster",
    "Foss",
    "Foster",
    "Fowler",
    "Fran",
    "Francesco",
    "Franchot",
    "Francis",
    "Francisco",
    "Franciskus",
    "Francklin",
    "Francklyn",
    "Francois",
    "Frank",
    "Frankie",
    "Franklin",
    "Franklyn",
    "Franky",
    "Frannie",
    "Franny",
    "Frans",
    "Fransisco",
    "Frants",
    "Franz",
    "Franzen",
    "Frasco",
    "Fraser",
    "Frasier",
    "Frasquito",
    "Fraze",
    "Frazer",
    "Frazier",
    "Fred",
    "Freddie",
    "Freddy",
    "Fredek",
    "Frederic",
    "Frederich",
    "Frederick",
    "Frederico",
    "Frederigo",
    "Frederik",
    "Fredric",
    "Fredrick",
    "Free",
    "Freedman",
    "Freeland",
    "Freeman",
    "Freemon",
    "Fremont",
    "Friedrich",
    "Friedrick",
    "Fritz",
    "Fulton",
    "Gabbie",
    "Gabby",
    "Gabe",
    "Gabi",
    "Gabie",
    "Gabriel",
    "Gabriele",
    "Gabriello",
    "Gaby",
    "Gael",
    "Gaelan",
    "Gage",
    "Gail",
    "Gaile",
    "Gal",
    "Gale",
    "Galen",
    "Gallagher",
    "Gallard",
    "Galvan",
    "Galven",
    "Galvin",
    "Gamaliel",
    "Gan",
    "Gannie",
    "Gannon",
    "Ganny",
    "Gar",
    "Garald",
    "Gard",
    "Gardener",
    "Gardie",
    "Gardiner",
    "Gardner",
    "Gardy",
    "Gare",
    "Garek",
    "Gareth",
    "Garey",
    "Garfield",
    "Garik",
    "Garner",
    "Garold",
    "Garrard",
    "Garrek",
    "Garret",
    "Garreth",
    "Garrett",
    "Garrick",
    "Garrik",
    "Garrot",
    "Garrott",
    "Garry",
    "Garth",
    "Garv",
    "Garvey",
    "Garvin",
    "Garvy",
    "Garwin",
    "Garwood",
    "Gary",
    "Gaspar",
    "Gaspard",
    "Gasparo",
    "Gasper",
    "Gaston",
    "Gaultiero",
    "Gauthier",
    "Gav",
    "Gavan",
    "Gaven",
    "Gavin",
    "Gawain",
    "Gawen",
    "Gay",
    "Gayelord",
    "Gayle",
    "Gayler",
    "Gaylor",
    "Gaylord",
    "Gearalt",
    "Gearard",
    "Gene",
    "Geno",
    "Geoff",
    "Geoffrey",
    "Geoffry",
    "Georas",
    "Geordie",
    "Georg",
    "George",
    "Georges",
    "Georgi",
    "Georgie",
    "Georgy",
    "Gerald",
    "Gerard",
    "Gerardo",
    "Gerek",
    "Gerhard",
    "Gerhardt",
    "Geri",
    "Gerick",
    "Gerik",
    "Germain",
    "Germaine",
    "Germayne",
    "Gerome",
    "Gerrard",
    "Gerri",
    "Gerrie",
    "Gerry",
    "Gery",
    "Gherardo",
    "Giacobo",
    "Giacomo",
    "Giacopo",
    "Gian",
    "Gianni",
    "Giavani",
    "Gib",
    "Gibb",
    "Gibbie",
    "Gibby",
    "Gideon",
    "Giff",
    "Giffard",
    "Giffer",
    "Giffie",
    "Gifford",
    "Giffy",
    "Gil",
    "Gilbert",
    "Gilberto",
    "Gilburt",
    "Giles",
    "Gill",
    "Gilles",
    "Ginger",
    "Gino",
    "Giordano",
    "Giorgi",
    "Giorgio",
    "Giovanni",
    "Giraldo",
    "Giraud",
    "Giselbert",
    "Giulio",
    "Giuseppe",
    "Giustino",
    "Giusto",
    "Glen",
    "Glenden",
    "Glendon",
    "Glenn",
    "Glyn",
    "Glynn",
    "Godard",
    "Godart",
    "Goddard",
    "Goddart",
    "Godfree",
    "Godfrey",
    "Godfry",
    "Godwin",
    "Gonzales",
    "Gonzalo",
    "Goober",
    "Goran",
    "Goraud",
    "Gordan",
    "Gorden",
    "Gordie",
    "Gordon",
    "Gordy",
    "Gothart",
    "Gottfried",
    "Grace",
    "Gradeigh",
    "Gradey",
    "Grady",
    "Graehme",
    "Graeme",
    "Graham",
    "Graig",
    "Gram",
    "Gran",
    "Grange",
    "Granger",
    "Grannie",
    "Granny",
    "Grant",
    "Grantham",
    "Granthem",
    "Grantley",
    "Granville",
    "Gray",
    "Greg",
    "Gregg",
    "Greggory",
    "Gregoire",
    "Gregoor",
    "Gregor",
    "Gregorio",
    "Gregorius",
    "Gregory",
    "Grenville",
    "Griff",
    "Griffie",
    "Griffin",
    "Griffith",
    "Griffy",
    "Gris",
    "Griswold",
    "Griz",
    "Grove",
    "Grover",
    "Gualterio",
    "Guglielmo",
    "Guido",
    "Guilbert",
    "Guillaume",
    "Guillermo",
    "Gun",
    "Gunar",
    "Gunner",
    "Guntar",
    "Gunter",
    "Gunther",
    "Gus",
    "Guss",
    "Gustaf",
    "Gustav",
    "Gustave",
    "Gustavo",
    "Gustavus",
    "Guthrey",
    "Guthrie",
    "Guthry",
    "Guy",
    "Had",
    "Hadlee",
    "Hadleigh",
    "Hadley",
    "Hadrian",
    "Hagan",
    "Hagen",
    "Hailey",
    "Haily",
    "Hakeem",
    "Hakim",
    "Hal",
    "Hale",
    "Haleigh",
    "Haley",
    "Hall",
    "Hallsy",
    "Halsey",
    "Halsy",
    "Ham",
    "Hamel",
    "Hamid",
    "Hamil",
    "Hamilton",
    "Hamish",
    "Hamlen",
    "Hamlin",
    "Hammad",
    "Hamnet",
    "Hanan",
    "Hank",
    "Hans",
    "Hansiain",
    "Hanson",
    "Harald",
    "Harbert",
    "Harcourt",
    "Hardy",
    "Harlan",
    "Harland",
    "Harlen",
    "Harley",
    "Harlin",
    "Harman",
    "Harmon",
    "Harold",
    "Haroun",
    "Harp",
    "Harper",
    "Harris",
    "Harrison",
    "Harry",
    "Hart",
    "Hartley",
    "Hartwell",
    "Harv",
    "Harvey",
    "Harwell",
    "Harwilll",
    "Hasheem",
    "Hashim",
    "Haskel",
    "Haskell",
    "Haslett",
    "Hastie",
    "Hastings",
    "Hasty",
    "Haven",
    "Hayden",
    "Haydon",
    "Hayes",
    "Hayward",
    "Haywood",
    "Hayyim",
    "Haze",
    "Hazel",
    "Hazlett",
    "Heall",
    "Heath",
    "Hebert",
    "Hector",
    "Heindrick",
    "Heinrick",
    "Heinrik",
    "Henderson",
    "Hendrick",
    "Hendrik",
    "Henri",
    "Henrik",
    "Henry",
    "Herb",
    "Herbert",
    "Herbie",
    "Herby",
    "Herc",
    "Hercule",
    "Hercules",
    "Herculie",
    "Heriberto",
    "Herman",
    "Hermann",
    "Hermie",
    "Hermon",
    "Hermy",
    "Hernando",
    "Herold",
    "Herrick",
    "Hersch",
    "Herschel",
    "Hersh",
    "Hershel",
    "Herve",
    "Hervey",
    "Hew",
    "Hewe",
    "Hewet",
    "Hewett",
    "Hewie",
    "Hewitt",
    "Heywood",
    "Hi",
    "Hieronymus",
    "Hilario",
    "Hilarius",
    "Hilary",
    "Hill",
    "Hillard",
    "Hillary",
    "Hillel",
    "Hillery",
    "Hilliard",
    "Hillie",
    "Hillier",
    "Hilly",
    "Hillyer",
    "Hilton",
    "Hinze",
    "Hiram",
    "Hirsch",
    "Hobard",
    "Hobart",
    "Hobey",
    "Hobie",
    "Hodge",
    "Hoebart",
    "Hogan",
    "Holden",
    "Hollis",
    "Holly",
    "Holmes",
    "Holt",
    "Homer",
    "Homere",
    "Homerus",
    "Horace",
    "Horacio",
    "Horatio",
    "Horatius",
    "Horst",
    "Hort",
    "Horten",
    "Horton",
    "Howard",
    "Howey",
    "Howie",
    "Hoyt",
    "Hube",
    "Hubert",
    "Huberto",
    "Hubey",
    "Hubie",
    "Huey",
    "Hugh",
    "Hughie",
    "Hugibert",
    "Hugo",
    "Hugues",
    "Humbert",
    "Humberto",
    "Humfrey",
    "Humfrid",
    "Humfried",
    "Humphrey",
    "Hunfredo",
    "Hunt",
    "Hunter",
    "Huntington",
    "Huntlee",
    "Huntley",
    "Hurlee",
    "Hurleigh",
    "Hurley",
    "Husain",
    "Husein",
    "Hussein",
    "Hy",
    "Hyatt",
    "Hyman",
    "Hymie",
    "Iago",
    "Iain",
    "Ian",
    "Ibrahim",
    "Ichabod",
    "Iggie",
    "Iggy",
    "Ignace",
    "Ignacio",
    "Ignacius",
    "Ignatius",
    "Ignaz",
    "Ignazio",
    "Igor",
    "Ike",
    "Ikey",
    "Ilaire",
    "Ilario",
    "Immanuel",
    "Ingamar",
    "Ingar",
    "Ingelbert",
    "Ingemar",
    "Inger",
    "Inglebert",
    "Inglis",
    "Ingmar",
    "Ingra",
    "Ingram",
    "Ingrim",
    "Inigo",
    "Inness",
    "Innis",
    "Iorgo",
    "Iorgos",
    "Iosep",
    "Ira",
    "Irv",
    "Irvin",
    "Irvine",
    "Irving",
    "Irwin",
    "Irwinn",
    "Isa",
    "Isaac",
    "Isaak",
    "Isac",
    "Isacco",
    "Isador",
    "Isadore",
    "Isaiah",
    "Isak",
    "Isiahi",
    "Isidor",
    "Isidore",
    "Isidoro",
    "Isidro",
    "Israel",
    "Issiah",
    "Itch",
    "Ivan",
    "Ivar",
    "Ive",
    "Iver",
    "Ives",
    "Ivor",
    "Izaak",
    "Izak",
    "Izzy",
    "Jabez",
    "Jack",
    "Jackie",
    "Jackson",
    "Jacky",
    "Jacob",
    "Jacobo",
    "Jacques",
    "Jae",
    "Jaime",
    "Jaimie",
    "Jake",
    "Jakie",
    "Jakob",
    "Jamaal",
    "Jamal",
    "James",
    "Jameson",
    "Jamesy",
    "Jamey",
    "Jamie",
    "Jamil",
    "Jamill",
    "Jamison",
    "Jammal",
    "Jan",
    "Janek",
    "Janos",
    "Jarad",
    "Jard",
    "Jareb",
    "Jared",
    "Jarib",
    "Jarid",
    "Jarrad",
    "Jarred",
    "Jarret",
    "Jarrett",
    "Jarrid",
    "Jarrod",
    "Jarvis",
    "Jase",
    "Jasen",
    "Jason",
    "Jasper",
    "Jasun",
    "Javier",
    "Jay",
    "Jaye",
    "Jayme",
    "Jaymie",
    "Jayson",
    "Jdavie",
    "Jean",
    "Jecho",
    "Jed",
    "Jedd",
    "Jeddy",
    "Jedediah",
    "Jedidiah",
    "Jeff",
    "Jefferey",
    "Jefferson",
    "Jeffie",
    "Jeffrey",
    "Jeffry",
    "Jeffy",
    "Jehu",
    "Jeno",
    "Jens",
    "Jephthah",
    "Jerad",
    "Jerald",
    "Jeramey",
    "Jeramie",
    "Jere",
    "Jereme",
    "Jeremiah",
    "Jeremias",
    "Jeremie",
    "Jeremy",
    "Jermain",
    "Jermaine",
    "Jermayne",
    "Jerome",
    "Jeromy",
    "Jerri",
    "Jerrie",
    "Jerrold",
    "Jerrome",
    "Jerry",
    "Jervis",
    "Jess",
    "Jesse",
    "Jessee",
    "Jessey",
    "Jessie",
    "Jesus",
    "Jeth",
    "Jethro",
    "Jim",
    "Jimmie",
    "Jimmy",
    "Jo",
    "Joachim",
    "Joaquin",
    "Job",
    "Jock",
    "Jocko",
    "Jodi",
    "Jodie",
    "Jody",
    "Joe",
    "Joel",
    "Joey",
    "Johan",
    "Johann",
    "Johannes",
    "John",
    "Johnathan",
    "Johnathon",
    "Johnnie",
    "Johnny",
    "Johny",
    "Jon",
    "Jonah",
    "Jonas",
    "Jonathan",
    "Jonathon",
    "Jone",
    "Jordan",
    "Jordon",
    "Jorgan",
    "Jorge",
    "Jory",
    "Jose",
    "Joseito",
    "Joseph",
    "Josh",
    "Joshia",
    "Joshua",
    "Joshuah",
    "Josiah",
    "Josias",
    "Jourdain",
    "Jozef",
    "Juan",
    "Jud",
    "Judah",
    "Judas",
    "Judd",
    "Jude",
    "Judon",
    "Jule",
    "Jules",
    "Julian",
    "Julie",
    "Julio",
    "Julius",
    "Justen",
    "Justin",
    "Justinian",
    "Justino",
    "Justis",
    "Justus",
    "Kahaleel",
    "Kahlil",
    "Kain",
    "Kaine",
    "Kaiser",
    "Kale",
    "Kaleb",
    "Kalil",
    "Kalle",
    "Kalvin",
    "Kane",
    "Kareem",
    "Karel",
    "Karim",
    "Karl",
    "Karlan",
    "Karlens",
    "Karlik",
    "Karlis",
    "Karney",
    "Karoly",
    "Kaspar",
    "Kasper",
    "Kayne",
    "Kean",
    "Keane",
    "Kearney",
    "Keary",
    "Keefe",
    "Keefer",
    "Keelby",
    "Keen",
    "Keenan",
    "Keene",
    "Keir",
    "Keith",
    "Kelbee",
    "Kelby",
    "Kele",
    "Kellby",
    "Kellen",
    "Kelley",
    "Kelly",
    "Kelsey",
    "Kelvin",
    "Kelwin",
    "Ken",
    "Kendal",
    "Kendall",
    "Kendell",
    "Kendrick",
    "Kendricks",
    "Kenn",
    "Kennan",
    "Kennedy",
    "Kenneth",
    "Kennett",
    "Kennie",
    "Kennith",
    "Kenny",
    "Kenon",
    "Kent",
    "Kenton",
    "Kenyon",
    "Ker",
    "Kerby",
    "Kerk",
    "Kermie",
    "Kermit",
    "Kermy",
    "Kerr",
    "Kerry",
    "Kerwin",
    "Kerwinn",
    "Kev",
    "Kevan",
    "Keven",
    "Kevin",
    "Kevon",
    "Khalil",
    "Kiel",
    "Kienan",
    "Kile",
    "Kiley",
    "Kilian",
    "Killian",
    "Killie",
    "Killy",
    "Kim",
    "Kimball",
    "Kimbell",
    "Kimble",
    "Kin",
    "Kincaid",
    "King",
    "Kingsley",
    "Kingsly",
    "Kingston",
    "Kinnie",
    "Kinny",
    "Kinsley",
    "Kip",
    "Kipp",
    "Kippar",
    "Kipper",
    "Kippie",
    "Kippy",
    "Kirby",
    "Kirk",
    "Kit",
    "Klaus",
    "Klemens",
    "Klement",
    "Kleon",
    "Kliment",
    "Knox",
    "Koenraad",
    "Konrad",
    "Konstantin",
    "Konstantine",
    "Korey",
    "Kort",
    "Kory",
    "Kris",
    "Krisha",
    "Krishna",
    "Krishnah",
    "Krispin",
    "Kristian",
    "Kristo",
    "Kristofer",
    "Kristoffer",
    "Kristofor",
    "Kristoforo",
    "Kristopher",
    "Kristos",
    "Kurt",
    "Kurtis",
    "Ky",
    "Kyle",
    "Kylie",
    "Laird",
    "Lalo",
    "Lamar",
    "Lambert",
    "Lammond",
    "Lamond",
    "Lamont",
    "Lance",
    "Lancelot",
    "Land",
    "Lane",
    "Laney",
    "Langsdon",
    "Langston",
    "Lanie",
    "Lannie",
    "Lanny",
    "Larry",
    "Lars",
    "Laughton",
    "Launce",
    "Lauren",
    "Laurence",
    "Laurens",
    "Laurent",
    "Laurie",
    "Lauritz",
    "Law",
    "Lawrence",
    "Lawry",
    "Lawton",
    "Lay",
    "Layton",
    "Lazar",
    "Lazare",
    "Lazaro",
    "Lazarus",
    "Lee",
    "Leeland",
    "Lefty",
    "Leicester",
    "Leif",
    "Leigh",
    "Leighton",
    "Lek",
    "Leland",
    "Lem",
    "Lemar",
    "Lemmie",
    "Lemmy",
    "Lemuel",
    "Lenard",
    "Lenci",
    "Lennard",
    "Lennie",
    "Leo",
    "Leon",
    "Leonard",
    "Leonardo",
    "Leonerd",
    "Leonhard",
    "Leonid",
    "Leonidas",
    "Leopold",
    "Leroi",
    "Leroy",
    "Les",
    "Lesley",
    "Leslie",
    "Lester",
    "Leupold",
    "Lev",
    "Levey",
    "Levi",
    "Levin",
    "Levon",
    "Levy",
    "Lew",
    "Lewes",
    "Lewie",
    "Lewiss",
    "Lezley",
    "Liam",
    "Lief",
    "Lin",
    "Linc",
    "Lincoln",
    "Lind",
    "Lindon",
    "Lindsay",
    "Lindsey",
    "Lindy",
    "Link",
    "Linn",
    "Linoel",
    "Linus",
    "Lion",
    "Lionel",
    "Lionello",
    "Lisle",
    "Llewellyn",
    "Lloyd",
    "Llywellyn",
    "Lock",
    "Locke",
    "Lockwood",
    "Lodovico",
    "Logan",
    "Lombard",
    "Lon",
    "Lonnard",
    "Lonnie",
    "Lonny",
    "Lorant",
    "Loren",
    "Lorens",
    "Lorenzo",
    "Lorin",
    "Lorne",
    "Lorrie",
    "Lorry",
    "Lothaire",
    "Lothario",
    "Lou",
    "Louie",
    "Louis",
    "Lovell",
    "Lowe",
    "Lowell",
    "Lowrance",
    "Loy",
    "Loydie",
    "Luca",
    "Lucais",
    "Lucas",
    "Luce",
    "Lucho",
    "Lucian",
    "Luciano",
    "Lucias",
    "Lucien",
    "Lucio",
    "Lucius",
    "Ludovico",
    "Ludvig",
    "Ludwig",
    "Luigi",
    "Luis",
    "Lukas",
    "Luke",
    "Lutero",
    "Luther",
    "Ly",
    "Lydon",
    "Lyell",
    "Lyle",
    "Lyman",
    "Lyn",
    "Lynn",
    "Lyon",
    "Mac",
    "Mace",
    "Mack",
    "Mackenzie",
    "Maddie",
    "Maddy",
    "Madison",
    "Magnum",
    "Mahmoud",
    "Mahmud",
    "Maison",
    "Maje",
    "Major",
    "Mal",
    "Malachi",
    "Malchy",
    "Malcolm",
    "Mallory",
    "Malvin",
    "Man",
    "Mandel",
    "Manfred",
    "Mannie",
    "Manny",
    "Mano",
    "Manolo",
    "Manuel",
    "Mar",
    "Marc",
    "Marcel",
    "Marcello",
    "Marcellus",
    "Marcelo",
    "Marchall",
    "Marco",
    "Marcos",
    "Marcus",
    "Marijn",
    "Mario",
    "Marion",
    "Marius",
    "Mark",
    "Markos",
    "Markus",
    "Marlin",
    "Marlo",
    "Marlon",
    "Marlow",
    "Marlowe",
    "Marmaduke",
    "Marsh",
    "Marshal",
    "Marshall",
    "Mart",
    "Martainn",
    "Marten",
    "Martie",
    "Martin",
    "Martino",
    "Marty",
    "Martyn",
    "Marv",
    "Marve",
    "Marven",
    "Marvin",
    "Marwin",
    "Mason",
    "Massimiliano",
    "Massimo",
    "Mata",
    "Mateo",
    "Mathe",
    "Mathew",
    "Mathian",
    "Mathias",
    "Matias",
    "Matt",
    "Matteo",
    "Matthaeus",
    "Mattheus",
    "Matthew",
    "Matthias",
    "Matthieu",
    "Matthiew",
    "Matthus",
    "Mattias",
    "Mattie",
    "Matty",
    "Maurice",
    "Mauricio",
    "Maurie",
    "Maurise",
    "Maurits",
    "Maurizio",
    "Maury",
    "Max",
    "Maxie",
    "Maxim",
    "Maximilian",
    "Maximilianus",
    "Maximilien",
    "Maximo",
    "Maxwell",
    "Maxy",
    "Mayer",
    "Maynard",
    "Mayne",
    "Maynord",
    "Mayor",
    "Mead",
    "Meade",
    "Meier",
    "Meir",
    "Mel",
    "Melvin",
    "Melvyn",
    "Menard",
    "Mendel",
    "Mendie",
    "Mendy",
    "Meredeth",
    "Meredith",
    "Merell",
    "Merill",
    "Merle",
    "Merrel",
    "Merrick",
    "Merrill",
    "Merry",
    "Merv",
    "Mervin",
    "Merwin",
    "Merwyn",
    "Meryl",
    "Meyer",
    "Mic",
    "Micah",
    "Michael",
    "Michail",
    "Michal",
    "Michale",
    "Micheal",
    "Micheil",
    "Michel",
    "Michele",
    "Mick",
    "Mickey",
    "Mickie",
    "Micky",
    "Miguel",
    "Mikael",
    "Mike",
    "Mikel",
    "Mikey",
    "Mikkel",
    "Mikol",
    "Mile",
    "Miles",
    "Mill",
    "Millard",
    "Miller",
    "Milo",
    "Milt",
    "Miltie",
    "Milton",
    "Milty",
    "Miner",
    "Minor",
    "Mischa",
    "Mitch",
    "Mitchael",
    "Mitchel",
    "Mitchell",
    "Moe",
    "Mohammed",
    "Mohandas",
    "Mohandis",
    "Moise",
    "Moises",
    "Moishe",
    "Monro",
    "Monroe",
    "Montague",
    "Monte",
    "Montgomery",
    "Monti",
    "Monty",
    "Moore",
    "Mord",
    "Mordecai",
    "Mordy",
    "Morey",
    "Morgan",
    "Morgen",
    "Morgun",
    "Morie",
    "Moritz",
    "Morlee",
    "Morley",
    "Morly",
    "Morrie",
    "Morris",
    "Morry",
    "Morse",
    "Mort",
    "Morten",
    "Mortie",
    "Mortimer",
    "Morton",
    "Morty",
    "Mose",
    "Moses",
    "Moshe",
    "Moss",
    "Mozes",
    "Muffin",
    "Muhammad",
    "Munmro",
    "Munroe",
    "Murdoch",
    "Murdock",
    "Murray",
    "Murry",
    "Murvyn",
    "My",
    "Myca",
    "Mycah",
    "Mychal",
    "Myer",
    "Myles",
    "Mylo",
    "Myron",
    "Myrvyn",
    "Myrwyn",
    "Nahum",
    "Nap",
    "Napoleon",
    "Nappie",
    "Nappy",
    "Nat",
    "Natal",
    "Natale",
    "Nataniel",
    "Nate",
    "Nathan",
    "Nathanael",
    "Nathanial",
    "Nathaniel",
    "Nathanil",
    "Natty",
    "Neal",
    "Neale",
    "Neall",
    "Nealon",
    "Nealson",
    "Nealy",
    "Ned",
    "Neddie",
    "Neddy",
    "Neel",
    "Nefen",
    "Nehemiah",
    "Neil",
    "Neill",
    "Neils",
    "Nels",
    "Nelson",
    "Nero",
    "Neron",
    "Nester",
    "Nestor",
    "Nev",
    "Nevil",
    "Nevile",
    "Neville",
    "Nevin",
    "Nevins",
    "Newton",
    "Nial",
    "Niall",
    "Niccolo",
    "Nicholas",
    "Nichole",
    "Nichols",
    "Nick",
    "Nickey",
    "Nickie",
    "Nicko",
    "Nickola",
    "Nickolai",
    "Nickolas",
    "Nickolaus",
    "Nicky",
    "Nico",
    "Nicol",
    "Nicola",
    "Nicolai",
    "Nicolais",
    "Nicolas",
    "Nicolis",
    "Niel",
    "Niels",
    "Nigel",
    "Niki",
    "Nikita",
    "Nikki",
    "Niko",
    "Nikola",
    "Nikolai",
    "Nikolaos",
    "Nikolas",
    "Nikolaus",
    "Nikolos",
    "Nikos",
    "Nil",
    "Niles",
    "Nils",
    "Nilson",
    "Niven",
    "Noach",
    "Noah",
    "Noak",
    "Noam",
    "Nobe",
    "Nobie",
    "Noble",
    "Noby",
    "Noe",
    "Noel",
    "Nolan",
    "Noland",
    "Noll",
    "Nollie",
    "Nolly",
    "Norbert",
    "Norbie",
    "Norby",
    "Norman",
    "Normand",
    "Normie",
    "Normy",
    "Norrie",
    "Norris",
    "Norry",
    "North",
    "Northrop",
    "Northrup",
    "Norton",
    "Nowell",
    "Nye",
    "Oates",
    "Obadiah",
    "Obadias",
    "Obed",
    "Obediah",
    "Oberon",
    "Obidiah",
    "Obie",
    "Oby",
    "Octavius",
    "Ode",
    "Odell",
    "Odey",
    "Odie",
    "Odo",
    "Ody",
    "Ogdan",
    "Ogden",
    "Ogdon",
    "Olag",
    "Olav",
    "Ole",
    "Olenolin",
    "Olin",
    "Oliver",
    "Olivero",
    "Olivier",
    "Oliviero",
    "Ollie",
    "Olly",
    "Olvan",
    "Omar",
    "Omero",
    "Onfre",
    "Onfroi",
    "Onofredo",
    "Oran",
    "Orazio",
    "Orbadiah",
    "Oren",
    "Orin",
    "Orion",
    "Orlan",
    "Orland",
    "Orlando",
    "Orran",
    "Orren",
    "Orrin",
    "Orson",
    "Orton",
    "Orv",
    "Orville",
    "Osbert",
    "Osborn",
    "Osborne",
    "Osbourn",
    "Osbourne",
    "Osgood",
    "Osmond",
    "Osmund",
    "Ossie",
    "Oswald",
    "Oswell",
    "Otes",
    "Othello",
    "Otho",
    "Otis",
    "Otto",
    "Owen",
    "Ozzie",
    "Ozzy",
    "Pablo",
    "Pace",
    "Packston",
    "Paco",
    "Pacorro",
    "Paddie",
    "Paddy",
    "Padget",
    "Padgett",
    "Padraic",
    "Padraig",
    "Padriac",
    "Page",
    "Paige",
    "Pail",
    "Pall",
    "Palm",
    "Palmer",
    "Panchito",
    "Pancho",
    "Paolo",
    "Papageno",
    "Paquito",
    "Park",
    "Parke",
    "Parker",
    "Parnell",
    "Parrnell",
    "Parry",
    "Parsifal",
    "Pascal",
    "Pascale",
    "Pasquale",
    "Pat",
    "Pate",
    "Paten",
    "Patin",
    "Paton",
    "Patric",
    "Patrice",
    "Patricio",
    "Patrick",
    "Patrizio",
    "Patrizius",
    "Patsy",
    "Patten",
    "Pattie",
    "Pattin",
    "Patton",
    "Patty",
    "Paul",
    "Paulie",
    "Paulo",
    "Pauly",
    "Pavel",
    "Pavlov",
    "Paxon",
    "Paxton",
    "Payton",
    "Peadar",
    "Pearce",
    "Pebrook",
    "Peder",
    "Pedro",
    "Peirce",
    "Pembroke",
    "Pen",
    "Penn",
    "Pennie",
    "Penny",
    "Penrod",
    "Pepe",
    "Pepillo",
    "Pepito",
    "Perceval",
    "Percival",
    "Percy",
    "Perice",
    "Perkin",
    "Pernell",
    "Perren",
    "Perry",
    "Pete",
    "Peter",
    "Peterus",
    "Petey",
    "Petr",
    "Peyter",
    "Peyton",
    "Phil",
    "Philbert",
    "Philip",
    "Phillip",
    "Phillipe",
    "Phillipp",
    "Phineas",
    "Phip",
    "Pierce",
    "Pierre",
    "Pierson",
    "Pieter",
    "Pietrek",
    "Pietro",
    "Piggy",
    "Pincas",
    "Pinchas",
    "Pincus",
    "Piotr",
    "Pip",
    "Pippo",
    "Pooh",
    "Port",
    "Porter",
    "Portie",
    "Porty",
    "Poul",
    "Powell",
    "Pren",
    "Prent",
    "Prentice",
    "Prentiss",
    "Prescott",
    "Preston",
    "Price",
    "Prince",
    "Prinz",
    "Pryce",
    "Puff",
    "Purcell",
    "Putnam",
    "Putnem",
    "Pyotr",
    "Quent",
    "Quentin",
    "Quill",
    "Quillan",
    "Quincey",
    "Quincy",
    "Quinlan",
    "Quinn",
    "Quint",
    "Quintin",
    "Quinton",
    "Quintus",
    "Rab",
    "Rabbi",
    "Rabi",
    "Rad",
    "Radcliffe",
    "Raddie",
    "Raddy",
    "Rafael",
    "Rafaellle",
    "Rafaello",
    "Rafe",
    "Raff",
    "Raffaello",
    "Raffarty",
    "Rafferty",
    "Rafi",
    "Ragnar",
    "Raimondo",
    "Raimund",
    "Raimundo",
    "Rainer",
    "Raleigh",
    "Ralf",
    "Ralph",
    "Ram",
    "Ramon",
    "Ramsay",
    "Ramsey",
    "Rance",
    "Rancell",
    "Rand",
    "Randal",
    "Randall",
    "Randell",
    "Randi",
    "Randie",
    "Randolf",
    "Randolph",
    "Randy",
    "Ransell",
    "Ransom",
    "Raoul",
    "Raphael",
    "Raul",
    "Ravi",
    "Ravid",
    "Raviv",
    "Rawley",
    "Ray",
    "Raymond",
    "Raymund",
    "Raynard",
    "Rayner",
    "Raynor",
    "Read",
    "Reade",
    "Reagan",
    "Reagen",
    "Reamonn",
    "Red",
    "Redd",
    "Redford",
    "Reece",
    "Reed",
    "Rees",
    "Reese",
    "Reg",
    "Regan",
    "Regen",
    "Reggie",
    "Reggis",
    "Reggy",
    "Reginald",
    "Reginauld",
    "Reid",
    "Reidar",
    "Reider",
    "Reilly",
    "Reinald",
    "Reinaldo",
    "Reinaldos",
    "Reinhard",
    "Reinhold",
    "Reinold",
    "Reinwald",
    "Rem",
    "Remington",
    "Remus",
    "Renado",
    "Renaldo",
    "Renard",
    "Renato",
    "Renaud",
    "Renault",
    "Rene",
    "Reube",
    "Reuben",
    "Reuven",
    "Rex",
    "Rey",
    "Reynard",
    "Reynold",
    "Reynolds",
    "Rhett",
    "Rhys",
    "Ric",
    "Ricard",
    "Ricardo",
    "Riccardo",
    "Rice",
    "Rich",
    "Richard",
    "Richardo",
    "Richart",
    "Richie",
    "Richmond",
    "Richmound",
    "Richy",
    "Rick",
    "Rickard",
    "Rickert",
    "Rickey",
    "Ricki",
    "Rickie",
    "Ricky",
    "Ricoriki",
    "Rik",
    "Rikki",
    "Riley",
    "Rinaldo",
    "Ring",
    "Ringo",
    "Riobard",
    "Riordan",
    "Rip",
    "Ripley",
    "Ritchie",
    "Roarke",
    "Rob",
    "Robb",
    "Robbert",
    "Robbie",
    "Robby",
    "Robers",
    "Robert",
    "Roberto",
    "Robin",
    "Robinet",
    "Robinson",
    "Rochester",
    "Rock",
    "Rockey",
    "Rockie",
    "Rockwell",
    "Rocky",
    "Rod",
    "Rodd",
    "Roddie",
    "Roddy",
    "Roderic",
    "Roderich",
    "Roderick",
    "Roderigo",
    "Rodge",
    "Rodger",
    "Rodney",
    "Rodolfo",
    "Rodolph",
    "Rodolphe",
    "Rodrick",
    "Rodrigo",
    "Rodrique",
    "Rog",
    "Roger",
    "Rogerio",
    "Rogers",
    "Roi",
    "Roland",
    "Rolando",
    "Roldan",
    "Roley",
    "Rolf",
    "Rolfe",
    "Rolland",
    "Rollie",
    "Rollin",
    "Rollins",
    "Rollo",
    "Rolph",
    "Roma",
    "Romain",
    "Roman",
    "Romeo",
    "Ron",
    "Ronald",
    "Ronnie",
    "Ronny",
    "Rooney",
    "Roosevelt",
    "Rorke",
    "Rory",
    "Rosco",
    "Roscoe",
    "Ross",
    "Rossie",
    "Rossy",
    "Roth",
    "Rourke",
    "Rouvin",
    "Rowan",
    "Rowen",
    "Rowland",
    "Rowney",
    "Roy",
    "Royal",
    "Royall",
    "Royce",
    "Rriocard",
    "Rube",
    "Ruben",
    "Rubin",
    "Ruby",
    "Rudd",
    "Ruddie",
    "Ruddy",
    "Rudie",
    "Rudiger",
    "Rudolf",
    "Rudolfo",
    "Rudolph",
    "Rudy",
    "Rudyard",
    "Rufe",
    "Rufus",
    "Ruggiero",
    "Rupert",
    "Ruperto",
    "Ruprecht",
    "Rurik",
    "Russ",
    "Russell",
    "Rustie",
    "Rustin",
    "Rusty",
    "Rutger",
    "Rutherford",
    "Rutledge",
    "Rutter",
    "Ruttger",
    "Ruy",
    "Ryan",
    "Ryley",
    "Ryon",
    "Ryun",
    "Sal",
    "Saleem",
    "Salem",
    "Salim",
    "Salmon",
    "Salomo",
    "Salomon",
    "Salomone",
    "Salvador",
    "Salvatore",
    "Salvidor",
    "Sam",
    "Sammie",
    "Sammy",
    "Sampson",
    "Samson",
    "Samuel",
    "Samuele",
    "Sancho",
    "Sander",
    "Sanders",
    "Sanderson",
    "Sandor",
    "Sandro",
    "Sandy",
    "Sanford",
    "Sanson",
    "Sansone",
    "Sarge",
    "Sargent",
    "Sascha",
    "Sasha",
    "Saul",
    "Sauncho",
    "Saunder",
    "Saunders",
    "Saunderson",
    "Saundra",
    "Sauveur",
    "Saw",
    "Sawyer",
    "Sawyere",
    "Sax",
    "Saxe",
    "Saxon",
    "Say",
    "Sayer",
    "Sayers",
    "Sayre",
    "Sayres",
    "Scarface",
    "Schuyler",
    "Scot",
    "Scott",
    "Scotti",
    "Scottie",
    "Scotty",
    "Seamus",
    "Sean",
    "Sebastian",
    "Sebastiano",
    "Sebastien",
    "See",
    "Selby",
    "Selig",
    "Serge",
    "Sergeant",
    "Sergei",
    "Sergent",
    "Sergio",
    "Seth",
    "Seumas",
    "Seward",
    "Seymour",
    "Shadow",
    "Shae",
    "Shaine",
    "Shalom",
    "Shamus",
    "Shanan",
    "Shane",
    "Shannan",
    "Shannon",
    "Shaughn",
    "Shaun",
    "Shaw",
    "Shawn",
    "Shay",
    "Shayne",
    "Shea",
    "Sheff",
    "Sheffie",
    "Sheffield",
    "Sheffy",
    "Shelby",
    "Shelden",
    "Shell",
    "Shelley",
    "Shelton",
    "Shem",
    "Shep",
    "Shepard",
    "Shepherd",
    "Sheppard",
    "Shepperd",
    "Sheridan",
    "Sherlock",
    "Sherlocke",
    "Sherm",
    "Sherman",
    "Shermie",
    "Shermy",
    "Sherwin",
    "Sherwood",
    "Sherwynd",
    "Sholom",
    "Shurlock",
    "Shurlocke",
    "Shurwood",
    "Si",
    "Sibyl",
    "Sid",
    "Sidnee",
    "Sidney",
    "Siegfried",
    "Siffre",
    "Sig",
    "Sigfrid",
    "Sigfried",
    "Sigismond",
    "Sigismondo",
    "Sigismund",
    "Sigismundo",
    "Sigmund",
    "Sigvard",
    "Silas",
    "Silvain",
    "Silvan",
    "Silvano",
    "Silvanus",
    "Silvester",
    "Silvio",
    "Sim",
    "Simeon",
    "Simmonds",
    "Simon",
    "Simone",
    "Sinclair",
    "Sinclare",
    "Siward",
    "Skell",
    "Skelly",
    "Skip",
    "Skipp",
    "Skipper",
    "Skippie",
    "Skippy",
    "Skipton",
    "Sky",
    "Skye",
    "Skylar",
    "Skyler",
    "Slade",
    "Sloan",
    "Sloane",
    "Sly",
    "Smith",
    "Smitty",
    "Sol",
    "Sollie",
    "Solly",
    "Solomon",
    "Somerset",
    "Son",
    "Sonnie",
    "Sonny",
    "Spence",
    "Spencer",
    "Spense",
    "Spenser",
    "Spike",
    "Stacee",
    "Stacy",
    "Staffard",
    "Stafford",
    "Staford",
    "Stan",
    "Standford",
    "Stanfield",
    "Stanford",
    "Stanislas",
    "Stanislaus",
    "Stanislaw",
    "Stanleigh",
    "Stanley",
    "Stanly",
    "Stanton",
    "Stanwood",
    "Stavro",
    "Stavros",
    "Stearn",
    "Stearne",
    "Stefan",
    "Stefano",
    "Steffen",
    "Stephan",
    "Stephanus",
    "Stephen",
    "Sterling",
    "Stern",
    "Sterne",
    "Steve",
    "Steven",
    "Stevie",
    "Stevy",
    "Steward",
    "Stewart",
    "Stillman",
    "Stillmann",
    "Stinky",
    "Stirling",
    "Stu",
    "Stuart",
    "Sullivan",
    "Sully",
    "Sumner",
    "Sunny",
    "Sutherlan",
    "Sutherland",
    "Sutton",
    "Sven",
    "Svend",
    "Swen",
    "Syd",
    "Sydney",
    "Sylas",
    "Sylvan",
    "Sylvester",
    "Syman",
    "Symon",
    "Tab",
    "Tabb",
    "Tabbie",
    "Tabby",
    "Taber",
    "Tabor",
    "Tad",
    "Tadd",
    "Taddeo",
    "Taddeusz",
    "Tadeas",
    "Tadeo",
    "Tades",
    "Tadio",
    "Tailor",
    "Tait",
    "Taite",
    "Talbert",
    "Talbot",
    "Tallie",
    "Tally",
    "Tam",
    "Tamas",
    "Tammie",
    "Tammy",
    "Tan",
    "Tann",
    "Tanner",
    "Tanney",
    "Tannie",
    "Tanny",
    "Tarrance",
    "Tate",
    "Taylor",
    "Teador",
    "Ted",
    "Tedd",
    "Teddie",
    "Teddy",
    "Tedie",
    "Tedman",
    "Tedmund",
    "Temp",
    "Temple",
    "Templeton",
    "Teodoor",
    "Teodor",
    "Teodorico",
    "Teodoro",
    "Terence",
    "Terencio",
    "Terrance",
    "Terrel",
    "Terrell",
    "Terrence",
    "Terri",
    "Terrill",
    "Terry",
    "Thacher",
    "Thaddeus",
    "Thaddus",
    "Thadeus",
    "Thain",
    "Thaine",
    "Thane",
    "Thatch",
    "Thatcher",
    "Thaxter",
    "Thayne",
    "Thebault",
    "Thedric",
    "Thedrick",
    "Theo",
    "Theobald",
    "Theodor",
    "Theodore",
    "Theodoric",
    "Thibaud",
    "Thibaut",
    "Thom",
    "Thoma",
    "Thomas",
    "Thor",
    "Thorin",
    "Thorn",
    "Thorndike",
    "Thornie",
    "Thornton",
    "Thorny",
    "Thorpe",
    "Thorstein",
    "Thorsten",
    "Thorvald",
    "Thurstan",
    "Thurston",
    "Tibold",
    "Tiebold",
    "Tiebout",
    "Tiler",
    "Tim",
    "Timmie",
    "Timmy",
    "Timofei",
    "Timoteo",
    "Timothee",
    "Timotheus",
    "Timothy",
    "Tirrell",
    "Tito",
    "Titos",
    "Titus",
    "Tobe",
    "Tobiah",
    "Tobias",
    "Tobie",
    "Tobin",
    "Tobit",
    "Toby",
    "Tod",
    "Todd",
    "Toddie",
    "Toddy",
    "Toiboid",
    "Tom",
    "Tomas",
    "Tomaso",
    "Tome",
    "Tomkin",
    "Tomlin",
    "Tommie",
    "Tommy",
    "Tonnie",
    "Tony",
    "Tore",
    "Torey",
    "Torin",
    "Torr",
    "Torrance",
    "Torre",
    "Torrence",
    "Torrey",
    "Torrin",
    "Torry",
    "Town",
    "Towney",
    "Townie",
    "Townsend",
    "Towny",
    "Trace",
    "Tracey",
    "Tracie",
    "Tracy",
    "Traver",
    "Travers",
    "Travis",
    "Travus",
    "Trefor",
    "Tremain",
    "Tremaine",
    "Tremayne",
    "Trent",
    "Trenton",
    "Trev",
    "Trevar",
    "Trever",
    "Trevor",
    "Trey",
    "Trip",
    "Tripp",
    "Tris",
    "Tristam",
    "Tristan",
    "Troy",
    "Trstram",
    "Trueman",
    "Trumaine",
    "Truman",
    "Trumann",
    "Tuck",
    "Tucker",
    "Tuckie",
    "Tucky",
    "Tudor",
    "Tull",
    "Tulley",
    "Tully",
    "Turner",
    "Ty",
    "Tybalt",
    "Tye",
    "Tyler",
    "Tymon",
    "Tymothy",
    "Tynan",
    "Tyrone",
    "Tyrus",
    "Tyson",
    "Udale",
    "Udall",
    "Udell",
    "Ugo",
    "Ulberto",
    "Ulick",
    "Ulises",
    "Ulric",
    "Ulrich",
    "Ulrick",
    "Ulysses",
    "Umberto",
    "Upton",
    "Urbain",
    "Urban",
    "Urbano",
    "Urbanus",
    "Uri",
    "Uriah",
    "Uriel",
    "Urson",
    "Vachel",
    "Vaclav",
    "Vail",
    "Val",
    "Valdemar",
    "Vale",
    "Valentijn",
    "Valentin",
    "Valentine",
    "Valentino",
    "Valle",
    "Van",
    "Vance",
    "Vanya",
    "Vasili",
    "Vasilis",
    "Vasily",
    "Vassili",
    "Vassily",
    "Vaughan",
    "Vaughn",
    "Verge",
    "Vergil",
    "Vern",
    "Verne",
    "Vernen",
    "Verney",
    "Vernon",
    "Vernor",
    "Vic",
    "Vick",
    "Victoir",
    "Victor",
    "Vidovic",
    "Vidovik",
    "Vin",
    "Vince",
    "Vincent",
    "Vincents",
    "Vincenty",
    "Vincenz",
    "Vinnie",
    "Vinny",
    "Vinson",
    "Virge",
    "Virgie",
    "Virgil",
    "Virgilio",
    "Vite",
    "Vito",
    "Vittorio",
    "Vlad",
    "Vladamir",
    "Vladimir",
    "Von",
    "Wade",
    "Wadsworth",
    "Wain",
    "Wainwright",
    "Wait",
    "Waite",
    "Waiter",
    "Wake",
    "Wakefield",
    "Wald",
    "Waldemar",
    "Walden",
    "Waldo",
    "Waldon",
    "Walker",
    "Wallace",
    "Wallache",
    "Wallas",
    "Wallie",
    "Wallis",
    "Wally",
    "Walsh",
    "Walt",
    "Walther",
    "Walton",
    "Wang",
    "Ward",
    "Warde",
    "Warden",
    "Ware",
    "Waring",
    "Warner",
    "Warren",
    "Wash",
    "Washington",
    "Wat",
    "Waverley",
    "Waverly",
    "Way",
    "Waylan",
    "Wayland",
    "Waylen",
    "Waylin",
    "Waylon",
    "Wayne",
    "Web",
    "Webb",
    "Weber",
    "Webster",
    "Weidar",
    "Weider",
    "Welbie",
    "Welby",
    "Welch",
    "Wells",
    "Welsh",
    "Wendall",
    "Wendel",
    "Wendell",
    "Werner",
    "Wernher",
    "Wes",
    "Wesley",
    "West",
    "Westbrook",
    "Westbrooke",
    "Westleigh",
    "Westley",
    "Weston",
    "Weylin",
    "Wheeler",
    "Whit",
    "Whitaker",
    "Whitby",
    "Whitman",
    "Whitney",
    "Whittaker",
    "Wiatt",
    "Wilbert",
    "Wilbur",
    "Wilburt",
    "Wilden",
    "Wildon",
    "Wilek",
    "Wiley",
    "Wilfred",
    "Wilfrid",
    "Wilhelm",
    "Will",
    "Willard",
    "Willdon",
    "Willem",
    "Willey",
    "Willi",
    "William",
    "Willie",
    "Willis",
    "Willy",
    "Wilmar",
    "Wilmer",
    "Wilt",
    "Wilton",
    "Win",
    "Windham",
    "Winfield",
    "Winfred",
    "Winifield",
    "Winn",
    "Winnie",
    "Winny",
    "Winslow",
    "Winston",
    "Winthrop",
    "Wit",
    "Wittie",
    "Witty",
    "Wolf",
    "Wolfgang",
    "Wolfie",
    "Wolfy",
    "Wood",
    "Woodie",
    "Woodman",
    "Woodrow",
    "Woody",
    "Worden",
    "Worth",
    "Worthington",
    "Worthy",
    "Wright",
    "Wyatan",
    "Wyatt",
    "Wye",
    "Wylie",
    "Wyn",
    "Wyndham",
    "Wynn",
    "Xavier",
    "Xenos",
    "Xerxes",
    "Xever",
    "Ximenes",
    "Ximenez",
    "Xymenes",
    "Yale",
    "Yanaton",
    "Yance",
    "Yancey",
    "Yancy",
    "Yank",
    "Yankee",
    "Yard",
    "Yardley",
    "Yehudi",
    "Yehudit",
    "Yorgo",
    "Yorgos",
    "York",
    "Yorke",
    "Yorker",
    "Yul",
    "Yule",
    "Yulma",
    "Yuma",
    "Yuri",
    "Yurik",
    "Yves",
    "Yvon",
    "Yvor",
    "Zaccaria",
    "Zach",
    "Zacharia",
    "Zachariah",
    "Zacharias",
    "Zacharie",
    "Zachary",
    "Zacherie",
    "Zachery",
    "Zack",
    "Zackariah",
    "Zak",
    "Zane",
    "Zared",
    "Zeb",
    "Zebadiah",
    "Zebedee",
    "Zebulen",
    "Zebulon",
    "Zechariah",
    "Zed",
    "Zedekiah",
    "Zeke",
    "Zelig",
    "Zerk",
    "Zollie",
    "Zolly",
]

tr_soyisimler = [
    "Abacioğlu",
    "Abat",
    "Abseyi",
    "Acar",
    "Acarbulut",
    "Adali",
    "Adanir",
    "Adigüzel",
    "Adisanli",
    "Afşar",
    "Ahiskali",
    "Ahçi",
    "Ak",
    "Ak Yildirim",
    "Akan",
    "Akansel",
    "Akar",
    "Akaslan",
    "Akay",
    "Akbaş",
    "Akbaş Öncel",
    "Akbudak",
    "Akbulut",
    "Akca Çağlar",
    "Akcan Atasoy",
    "Akcan Paksoy",
    "Akdemir",
    "Akdeniz",
    "Akdoğan",
    "Akduman",
    "Akel",
    "Akgül",
    "Akgün",
    "Akhun",
    "Akin",
    "Akinci",
    "Akiş",
    "Akkan",
    "Akkaya",
    "Akkaş",
    "Akkoyun",
    "Akkoyunlu",
    "Akman",
    "Akmeşe",
    "Akova",
    "Akpinar",
    "Aksakal",
    "Aksaç",
    "Aksel",
    "Aksoy",
    "Aksu",
    "Aksun",
    "Aksöz",
    "Aktan",
    "Aktaş",
    "Aktemur",
    "Aktuğ",
    "Aktürk",
    "Akyilmaz",
    "Akyol",
    "Akyürek",
    "Akyüz",
    "Akçali",
    "Akçay",
    "Akçayir",
    "Aköz",
    "Akşahin",
    "Al",
    "Alabalik",
    "Aladağ",
    "Alan",
    "Alay",
    "Alaybeyoğlu",
    "Albay",
    "Albayrak",
    "Albaş",
    "Alben",
    "Alboğa",
    "Aldinç",
    "Alici",
    "Alim",
    "Alimli",
    "Alişik",
    "Alkaç",
    "Alkiş",
    "Alkurt Kayikçi",
    "Almacioğlu",
    "Almofti",
    "Alp",
    "Alparslan",
    "Alpayci",
    "Alpinar",
    "Alpsan Gökmen",
    "Altaş",
    "Altin",
    "Altinboğa",
    "Altinsoy",
    "Altun",
    "Altuna",
    "Altuntaş",
    "Altunyaprak",
    "Altunöz",
    "Aluçlu",
    "Alğan",
    "Amirova Uçan",
    "Anik",
    "Apaydin",
    "Araci",
    "Ararat",
    "Aras",
    "Araz Server",
    "Arda",
    "Ardiç",
    "Arga",
    "Argon",
    "Ari",
    "Arici",
    "Arifoğlu",
    "Arik",
    "Arikan",
    "Arikan Yorgun",
    "Arikboğa",
    "Arkan",
    "Armağan",
    "Arpat",
    "Arslan",
    "Arslan Kaşdoğan",
    "Arslankeçecioğlu",
    "Arslanoğlu",
    "Artuç",
    "Asena",
    "Asig",
    "Asil",
    "Aslan",
    "Aslanalp",
    "Aslaner",
    "Aslankara",
    "Asoğlu",
    "Atabay",
    "Atak",
    "Atalay",
    "Atar",
    "Atasoy",
    "Atay",
    "Atbaş",
    "Atbinici",
    "Atci",
    "Ateş",
    "Ateş Budak",
    "Atik",
    "Atila",
    "Atilgan",
    "Atilla",
    "Atlanoğlu",
    "Atmiş",
    "Atçeken",
    "Avci",
    "Avcioğlu",
    "Avcu",
    "Avlanir",
    "Avseren",
    "Avşar",
    "Ay Güney",
    "Ayas",
    "Ayaz",
    "Aycan",
    "Aydemir",
    "Aydin",
    "Aydin Badillioğlu",
    "Aydiner",
    "Aydos",
    "Aydoğan",
    "Ayduğan",
    "Ayhan",
    "Ayik",
    "Aykan",
    "Aykol",
    "Aykuş",
    "Ayman",
    "Ayranci",
    "Aytaç",
    "Aytekin",
    "Ayvaz",
    "Ayyildiz",
    "Azak",
    "Azap",
    "Azar",
    "Azrak",
    "Açar",
    "Açikgöz",
    "Ağca",
    "Aşan",
    "Aşik",
    "Aşkin",
    "Baba",
    "Babacan",
    "Babadaği",
    "Babayiğit",
    "Babuş",
    "Bacak",
    "Bacaksiz",
    "Badem",
    "Baglars",
    "Bahadir",
    "Bahçebaşi",
    "Bahçeci",
    "Bak",
    "Bakan",
    "Bakanay Öztürk",
    "Bakar",
    "Bakay",
    "Bakirci",
    "Baklaci",
    "Baklali",
    "Bal",
    "Balaban",
    "Balal",
    "Balci",
    "Balli",
    "Baloğlu",
    "Balsak",
    "Balta",
    "Baltaci",
    "Baran",
    "Baratali",
    "Barbaros",
    "Bardakçi",
    "Barişan",
    "Barut",
    "Barça",
    "Barçak",
    "Batgi Azarkan",
    "Batmaz",
    "Batçik",
    "Bayam",
    "Bayana",
    "Bayar",
    "Baygeldi",
    "Bayhan",
    "Baymak",
    "Bayrak",
    "Bayraktar",
    "Bayraktaroğlu",
    "Bayrakçi",
    "Bayram",
    "Bayramoğlu",
    "Baysal",
    "Baysoy",
    "Baytan",
    "Baz",
    "Baziki",
    "Bağ",
    "Bağci",
    "Bağcik",
    "Bağli",
    "Baş",
    "Başak",
    "Başar",
    "Başaran",
    "Başargan",
    "Başci",
    "Başdaş",
    "Başer",
    "Başkak",
    "Başkan",
    "Başkan Vuralkan",
    "Başman",
    "Baştemir",
    "Baştürk Ayhan",
    "Başyiğit",
    "Başyurt",
    "Beder",
    "Bekar",
    "Bekler",
    "Bektaş",
    "Belgemen",
    "Berber",
    "Berekatoğlu",
    "Bereket",
    "Berent",
    "Berk",
    "Berkay",
    "Bertan",
    "Beyoğlu",
    "Bican",
    "Bilal",
    "Bilge",
    "Bilgi",
    "Bilgin",
    "Bilgiç",
    "Bilici",
    "Binboğa",
    "Binnetoğlu",
    "Biri",
    "Biçakçi",
    "Biçer",
    "Bobuşoğlu",
    "Boduroğlu",
    "Bolat",
    "Bolatkale",
    "Bolattürk",
    "Bolaç",
    "Bolkan",
    "Bolsoy",
    "Bostankolu",
    "Bozan",
    "Bozarslan",
    "Bozkurt",
    "Bozkurter",
    "Bozkuş",
    "Bozoğlan",
    "Bozoğlu",
    "Bozpolat",
    "Boğan",
    "Budunoğlu",
    "Bulakçi",
    "Bulur",
    "Bulut",
    "Buluç",
    "Burak",
    "Burulday",
    "Buğrul",
    "Böcü",
    "Bölük",
    "Bölükbaş",
    "Börta",
    "Böyük",
    "Büber",
    "Büdün",
    "Bükülmez",
    "Büküm",
    "Bülbül",
    "Bürkük",
    "Büyük",
    "Büyükbulut",
    "Büyükcam",
    "Büyükceran",
    "Büyükdoğan",
    "Büyükkal",
    "Büyükkalayci",
    "Büyükpastirmaci",
    "Büyüktaş",
    "Caf",
    "Camci",
    "Camgöz",
    "Can",
    "Can Boran",
    "Canacankatan",
    "Canatan",
    "Canbaz",
    "Canbolat",
    "Candan",
    "Candaner",
    "Candemir",
    "Canik",
    "Canpolat",
    "Cansever",
    "Cantay",
    "Cantürk",
    "Cebeci",
    "Celiloğlu",
    "Celtemen",
    "Cengiz",
    "Ceran",
    "Cerit",
    "Ceylan",
    "Ciliz Basheer",
    "Cimbek",
    "Cinbiz",
    "Cindemir",
    "Cirit Koçer",
    "Corut",
    "Coşar",
    "Coşgun",
    "Coşkun",
    "Coşkuner",
    "Cömert",
    "Dadali",
    "Dadli",
    "Dal",
    "Dalyan Cilo",
    "Dam",
    "Danişoğlu",
    "Daraman",
    "Dayangaç",
    "Daylak",
    "Dağ",
    "Dağdelen",
    "Dağli",
    "Dağlioğlu",
    "Dede",
    "Dedemoğlu",
    "Dedeoğlu",
    "Demir",
    "Demir Göçmen",
    "Demiray",
    "Demirbaş",
    "Demircan",
    "Demirdağ",
    "Demirel",
    "Demirelli",
    "Demirer",
    "Demirgan",
    "Demirhan",
    "Demirkapi",
    "Demirkol",
    "Demirtaş",
    "Demirtürk",
    "Demiröz",
    "Deniz",
    "Dere",
    "Derhem",
    "Destegül",
    "Deveci",
    "Develi",
    "Değirmenci",
    "Değirmenci Akar",
    "Dikici",
    "Dikoğlu",
    "Dil",
    "Dilek",
    "Dilli",
    "Dilmen",
    "Dincer",
    "Dinler",
    "Dinçer",
    "Dirican",
    "Divarci",
    "Dokumacioğlu",
    "Doruk",
    "Doğan",
    "Doğangüzel",
    "Duman",
    "Dumlu",
    "Dumludağ",
    "Duran",
    "Durman",
    "Durmaz",
    "Durmuş",
    "Dursun",
    "Duruk",
    "Durç Öztürk",
    "Duyan",
    "Duysak",
    "Duyu",
    "Dökmeci",
    "Dönertaş",
    "Dönmez",
    "Düger",
    "Dündar",
    "Düz",
    "Düzce",
    "Düzel",
    "Düzgün",
    "Düzkalir",
    "Efe",
    "Eken",
    "Eker",
    "Ekici",
    "Ekinci",
    "Ekiz",
    "Elbüken",
    "Eldem",
    "Elgörmüş",
    "Elik",
    "Ellialti",
    "Elmaağaç",
    "Elverdi",
    "Elçi",
    "Elçiçek",
    "Emeli",
    "Emet",
    "Emirlioğlu",
    "Emlakçioğlu",
    "Emlek",
    "Emre",
    "Engiz",
    "Eraslan",
    "Erat",
    "Erbaş",
    "Ercan",
    "Erdal",
    "Erdağ",
    "Erdem",
    "Erdem Özcan",
    "Erden",
    "Erdoğan",
    "Erdoğmuş",
    "Erel",
    "Eren",
    "Erge",
    "Erginel",
    "Ergintürk Acar",
    "Ergöz",
    "Ergülü Eşmen",
    "Ergün",
    "Erkan",
    "Erken",
    "Erkuran",
    "Erol",
    "Eroğlu",
    "Ersoy",
    "Ersöz",
    "Ertan",
    "Ertaş",
    "Ertekin",
    "Ertem",
    "Ertürk",
    "Ertürkler",
    "Eryavuz",
    "Eryilmaz",
    "Erzurum",
    "Erşen",
    "Esen",
    "Eser",
    "Eskimez",
    "Esmeray",
    "Etleç",
    "Evci",
    "Evik",
    "Evmez",
    "Evran",
    "Evren",
    "Evrenos",
    "Eyisoy",
    "Eylen",
    "Eyüp",
    "Ezer",
    "Eşfer",
    "Eşkazan",
    "Eşme",
    "Fakioğlu",
    "Feyzullahoğlu",
    "Fidan",
    "Filiz",
    "Filizay",
    "Findik Güvendi",
    "Firat",
    "Fişekci",
    "Gayretli Aydin",
    "Gazeteci Tekin",
    "Gazi",
    "Gedik Yilmaz",
    "Gedikli",
    "Gedük",
    "Gelegen",
    "Gencan",
    "Genel",
    "Genez",
    "Genç",
    "Genç Talas",
    "Gençdal",
    "Gençer",
    "Gençpinar",
    "Gençtürk",
    "Gerdan",
    "Gerger",
    "Gerilmez",
    "Geyik",
    "Gezici",
    "Geçmen",
    "Gider",
    "Giniş",
    "Giray",
    "Göde",
    "Gök",
    "Gökalp",
    "Gökce",
    "Gökgül",
    "Gökkoca",
    "Gökmeydan",
    "Göksel",
    "Göksoy",
    "Göktaş",
    "Gökten",
    "Göktepe",
    "Göktürk",
    "Gökçe",
    "Gökçek",
    "Gökçen",
    "Gölemez",
    "Göncü",
    "Gördük",
    "Görenekli",
    "Görkem",
    "Görmeli",
    "Görmüş",
    "Görünmez",
    "Gözaçan",
    "Gözcü",
    "Gözkaya",
    "Gözügül",
    "Göçen",
    "Gül",
    "Gül Özmen",
    "Gülbahar",
    "Gülcan",
    "Güldamla",
    "Gülen",
    "Gülen Akküçük",
    "Gülenay Sümer",
    "Güler",
    "Güleç",
    "Güleşen",
    "Güllü",
    "Gülsoy",
    "Gültekin",
    "Gülşan",
    "Gülşen",
    "Gümürdü",
    "Gümüş",
    "Gümüşay",
    "Gümüşçü",
    "Günay",
    "Günaydin",
    "Günbey",
    "Gündoğdu",
    "Gündüz",
    "Günebakan",
    "Güney Kocabaş",
    "Güneysu",
    "Güneş",
    "Güngör",
    "Güngör Uzunoğlu",
    "Güngörmez",
    "Günyel",
    "Gürakan",
    "Gürbostan",
    "Gürbüz",
    "Gürdal",
    "Gürdemir",
    "Gürel",
    "Gürer",
    "Gürpinar",
    "Gürsoy",
    "Güven",
    "Güven Meşe",
    "Güvenç",
    "Güvercin",
    "Güveren",
    "Güzel",
    "Güzelküçük",
    "Güçlü",
    "Hakyol",
    "Halhalli",
    "Halici",
    "Halis",
    "Hamdemirci",
    "Hancioğlu",
    "Hassan",
    "Hatipoğlu",
    "Havas",
    "Haşimoğlu",
    "Hepkaya",
    "Heybet",
    "Hidiroğlu",
    "Hiçdurmaz",
    "Hiçyilmaz",
    "Hodjaoglu",
    "Hoşer",
    "Höke",
    "Hüseyinoğlu",
    "Hüseyni",
    "Ilgin",
    "Issi",
    "Işik",
    "Işikalan",
    "Işikli",
    "Kaan",
    "Kaba",
    "Kabacaoğlu",
    "Kabakuş",
    "Kabil Kucur",
    "Kacemer",
    "Kadak",
    "Kadi",
    "Kahraman",
    "Kahreman",
    "Kahya",
    "Kala",
    "Kalem",
    "Kalipci",
    "Kalkan",
    "Kalyenci",
    "Kalyoncu Uçar",
    "Kamaci",
    "Kan",
    "Kanat",
    "Kandemir",
    "Kanik Yüksek",
    "Kankiliç",
    "Kanneci",
    "Kansu",
    "Kanyilmaz",
    "Kapar",
    "Kaplan",
    "Kaplankiran",
    "Kapçak",
    "Kara",
    "Karaalp",
    "Karaarslan",
    "Karaaslan",
    "Karaağaç",
    "Karabağ",
    "Karabulut",
    "Karaca",
    "Karacan",
    "Karacan Erşekerci",
    "Karadavut",
    "Karadağ",
    "Karadağ Geçgel",
    "Karadaş",
    "Karademir",
    "Karadeniz",
    "Karaduman",
    "Karadurak",
    "Karagöz",
    "Karahan",
    "Karaismailoğlu",
    "Karakan",
    "Karakaya",
    "Karakaş",
    "Karakiliç",
    "Karakoyun",
    "Karakoyunlu",
    "Karakulak",
    "Karakum",
    "Karakurt",
    "Karakuş",
    "Karakuş Epçaçan",
    "Karakök Güngör",
    "Karaköse",
    "Karalar",
    "Karamahmutoğlu",
    "Karaman",
    "Karamanli",
    "Karameşe",
    "Karan",
    "Karaoğlanoğlu",
    "Karaoğlu",
    "Karapiçak",
    "Karasu",
    "Karataş",
    "Karatoprak",
    "Karcioğlu",
    "Kardaş",
    "Karkin",
    "Karli",
    "Karnas",
    "Karpuz",
    "Karpuzoğlu",
    "Karsli",
    "Kartal",
    "Karçin",
    "Kasap",
    "Kasapoğlu",
    "Kaskalan",
    "Katran",
    "Kavmaz",
    "Kavukoğlu",
    "Kavurgaci",
    "Kaya",
    "Kayaalp",
    "Kayabaş",
    "Kayacan",
    "Kayaoğlu",
    "Kayayurt",
    "Kayhan",
    "Kayihan",
    "Kayka",
    "Kayki",
    "Kaykisiz",
    "Kaylan",
    "Kayman Köse",
    "Kaynak",
    "Kayra",
    "Kazan",
    "Kazanci",
    "Kazbek",
    "Kaçer",
    "Kaçira",
    "Kaşikçi",
    "Kebapcilar",
    "Keklikçioğlu",
    "Kelercioğlu",
    "Keleş",
    "Kemik",
    "Kendirli",
    "Kerimoğlu",
    "Keser",
    "Kesgin",
    "Kesik",
    "Kesim",
    "Keskin",
    "Kevkir",
    "Keçeci",
    "Keşkek",
    "Khalil",
    "Kilavuz",
    "Kilaç",
    "Kilbacak",
    "Kilinç",
    "Kiliç",
    "Kiliç Yildirim",
    "Kiliçcioğlu",
    "Kiliçoğlu",
    "Kinalioğlu",
    "Kindir",
    "Kinik",
    "Kir",
    "Kiran",
    "Kiraslan",
    "Kiraz",
    "Kiraç",
    "Kirbaş",
    "Kircali",
    "Kireççi",
    "Kirhan",
    "Kiriş",
    "Kirişci",
    "Kirlangiç",
    "Kirli",
    "Kisa",
    "Kisa Karakaya",
    "Kisaoğlu",
    "Kitay",
    "Kivrak",
    "Kiyak",
    "Kiyak Yilmaz",
    "Kizanoğlu",
    "Kizildağ",
    "Kizilmeşe",
    "Kiziltepe",
    "Kiziltoprak",
    "Kizmaz",
    "Kizmazoğlu",
    "Kişi",
    "Koca",
    "Kocabaş",
    "Kocabiyik",
    "Kocakaya Altundal",
    "Kocaman",
    "Kocasaraç",
    "Kocayiğit",
    "Kocubeyoğlu",
    "Kol",
    "Kolsuz",
    "Koluş",
    "Konuk",
    "Konuralp",
    "Kopan",
    "Koptur",
    "Kor",
    "Korkmaz",
    "Korkmazoğlu",
    "Korkut",
    "Korucu",
    "Kottaş",
    "Koyuncu",
    "Kozanoğlu",
    "Koç",
    "Koçar",
    "Koçarslan",
    "Koçer",
    "Koçoğlu",
    "Koçyiğit",
    "Kubat",
    "Kucur Tülübaş",
    "Kuday",
    "Kula",
    "Kulak Gedik",
    "Kulaksiz",
    "Kulaç",
    "Kumbul",
    "Kumral",
    "Kunak",
    "Kuralay",
    "Kurt",
    "Kurt Güney",
    "Kurtpinar",
    "Kurtuluş",
    "Kuru",
    "Kurul",
    "Kuserli",
    "Kutan",
    "Kutlar",
    "Kutlucan Bağci",
    "Kutluyurdu",
    "Kuyucu",
    "Kuş",
    "Kuşakçi",
    "Kuşku",
    "Köksal",
    "Köksoy",
    "Köroğlu",
    "Köse",
    "Köseoğlu",
    "Köycü",
    "Köylü",
    "Köylüoğlu",
    "Köşker",
    "Küfeciler",
    "Kütük",
    "Kütükcü",
    "Kütükoğlu",
    "Küçük",
    "Küçükceran",
    "Küçükgöncü",
    "Küçükyildiz",
    "Küçüközkan",
    "Lağarli",
    "Levent",
    "Leymunçiçeği",
    "Malçok",
    "Manav",
    "Mart",
    "Mavi",
    "Mağatur",
    "Melekoğlu",
    "Memetoğlu",
    "Memiş",
    "Mendeş",
    "Menekşe",
    "Menteş",
    "Mercan",
    "Merden",
    "Merhametsiz",
    "Mersin",
    "Mert",
    "Mertol",
    "Mesci Haftaci",
    "Mete",
    "Metineren",
    "Mirza",
    "Molla",
    "Moran",
    "Mumcuoğlu",
    "Murt",
    "Mutlu",
    "Mutluer",
    "Mönür",
    "Müezzinoğlu",
    "Müftüoğlu",
    "Nacar",
    "Nacaroğlu",
    "Nadastepe",
    "Nalbant",
    "Nar",
    "Nart",
    "Nasiroğlu",
    "Nasuhbeyoğlu",
    "Nimetigil",
    "Nizam",
    "Nozoğlu",
    "Nuhveren",
    "Nurlu",
    "Nurçin",
    "Ocak",
    "Oflaz",
    "Oflazoğlu",
    "Oktay",
    "Okudan",
    "Okulu",
    "Okur",
    "Okçu",
    "Olcar",
    "Olgaç",
    "Olgen",
    "Olmaz",
    "Olpak",
    "Omay",
    "Onan",
    "Onar Şekerci",
    "Onat",
    "Onay",
    "Onrat",
    "Onuk",
    "Orak",
    "Oral",
    "Ordulu Şahin",
    "Orhan",
    "Orhon",
    "Orman",
    "Orta",
    "Osmanca",
    "Oynak",
    "Ozan",
    "Oğuz",
    "Oğuzsoy",
    "Paksoy",
    "Paköz",
    "Para",
    "Parasiz",
    "Parlak",
    "Pazir",
    "Pehlivan",
    "Pekdoğan",
    "Pekel",
    "Peker",
    "Pekgöz",
    "Pektaş",
    "Peynirci",
    "Pinarbaşili",
    "Pirdoğan",
    "Piri",
    "Pirim",
    "Pirti",
    "Pişirgen",
    "Polat",
    "Polat Çiçek",
    "Postalli",
    "Pota",
    "Pulat",
    "Rençber",
    "Saatçioğlu",
    "Sabaz",
    "Sadi Aykan",
    "Sadiç",
    "Sadunoğlu",
    "Saf",
    "Sak",
    "Saka",
    "Sakalli",
    "Sakallioğlu",
    "Sakarya",
    "Saldiray",
    "Salman Sever",
    "Saltürk",
    "Sancar",
    "Sandal",
    "Sanhal",
    "Sansarci",
    "Saral",
    "Sarayli",
    "Saraç",
    "Saraçoğlu",
    "Saraçoğlu Çekiç",
    "Sargin",
    "Sari",
    "Sarica Darol",
    "Saricanbaz",
    "Sariekiz",
    "Sarigül",
    "Sarikaya",
    "Sariçiçek",
    "Sarp",
    "Savaş",
    "Savran",
    "Savğa",
    "Saygin",
    "Sayin",
    "Sayiner",
    "Sayyiğit",
    "Saçli",
    "Sağ",
    "Sağcan",
    "Sağdik",
    "Sağir",
    "Sağlam",
    "Sekin",
    "Selim",
    "Selvan",
    "Selvi",
    "Selvioğlu",
    "Selçuk",
    "Semerci",
    "Senemtaşi",
    "Serbest",
    "Serin",
    "Sert",
    "Sertel",
    "Sertkaya",
    "Sertkayaoğlu",
    "Sertoğlu",
    "Servet",
    "Seven",
    "Sever",
    "Sevimli",
    "Sevingil",
    "Sevinç",
    "Sevük",
    "Seyhan",
    "Seyrek",
    "Seyrekoğlu",
    "Sezen",
    "Sezer",
    "Sezgin",
    "Seçir",
    "Seçkin",
    "Seğmen",
    "Sil",
    "Sinici",
    "Sipahi",
    "Sivri",
    "Siğa",
    "Sobay",
    "Soluk",
    "Somay",
    "Sonay",
    "Sorgun Evcili",
    "Soydan",
    "Soyer",
    "Soykamer",
    "Soytaş",
    "Su",
    "Su Dur",
    "Su Kurt",
    "Subari",
    "Sucak",
    "Sulhan",
    "Sultanoğlu",
    "Suluova",
    "Suman",
    "Sungar",
    "Susam",
    "Suvari",
    "Suzan",
    "Söker",
    "Sökmen",
    "Sönmez",
    "Sönmezer",
    "Söylemez",
    "Söyler",
    "Sözen",
    "Sözer",
    "Sül",
    "Sülük",
    "Sümer",
    "Süner",
    "Sürmen Akyol",
    "Sürücü",
    "Sürüm",
    "Süveran",
    "Tacir",
    "Tahtaci",
    "Talan",
    "Talas",
    "Tan",
    "Tanin",
    "Taniş",
    "Tanrikulu",
    "Tanriverdi",
    "Tanriverdi Yilmaz",
    "Tantekin",
    "Tarakci",
    "Tarkan",
    "Tarlan",
    "Tatar",
    "Tatli",
    "Tavşan",
    "Tay",
    "Tayfun",
    "Tayfur",
    "Tayyar",
    "Tazeoğlu",
    "Taş",
    "Taşar",
    "Taşci",
    "Taşdelen",
    "Taşkin",
    "Taşkiran",
    "Taşli",
    "Taşmali",
    "Taştekin",
    "Tehli",
    "Teker",
    "Tekin",
    "Tekinsoy",
    "Tekir",
    "Tekiş",
    "Tel Kankiliç",
    "Temel",
    "Temiz",
    "Temli",
    "Temurtaş",
    "Ten",
    "Tenekeci",
    "Teoman",
    "Tepe",
    "Tevdik",
    "Tezel",
    "Tezer",
    "Teğin",
    "Tikici",
    "Tilbe",
    "Timurtaş Dayar",
    "Tiraş",
    "Tohumoğlu",
    "Tokar",
    "Tokat",
    "Tokatlioğlu",
    "Toker",
    "Tokmak",
    "Toktaş",
    "Tola",
    "Tolu",
    "Tombul",
    "Topak",
    "Topal",
    "Topalkara",
    "Topaloğlu",
    "Topcuoğlu",
    "Toper",
    "Topkara",
    "Toprak",
    "Toptaş",
    "Topuz",
    "Topçu",
    "Toy",
    "Toyran",
    "Tozlu",
    "Toşur",
    "Tuncay",
    "Tuncel",
    "Tuncer",
    "Tunç",
    "Tunçay",
    "Turan",
    "Turanoğlu",
    "Turaç",
    "Turgut",
    "Turmuş",
    "Turğut",
    "Tutar",
    "Tutaş",
    "Tuğcugil",
    "Tönge",
    "Tüfekçi",
    "Tüfenk",
    "Tülpar",
    "Tülüce",
    "Türe",
    "Türemenoğullari",
    "Türkay",
    "Türkdoğan",
    "Türkmen Albayrak",
    "Türkoğlu",
    "Türksoy",
    "Türkyilmaz",
    "Tüten",
    "Ufacik",
    "Ulaş",
    "Ulu",
    "Uluba",
    "Ulubaşoğlu",
    "Ulusoy",
    "Ulutaş",
    "Uluöz",
    "Ural",
    "Urfali",
    "Uruç",
    "Uslu",
    "Uslubaş",
    "Uslusoy",
    "Usta Güç",
    "Usul",
    "Utlu",
    "Uyanik",
    "Uyar",
    "Uygur",
    "Uykur",
    "Uysal",
    "Uyğun",
    "Uz",
    "Uzun",
    "Uzunca",
    "Uzuncan",
    "Uçar",
    "Uğurlu",
    "Uğuz",
    "Varici",
    "Varol",
    "Vatansever",
    "Veziroğlu Birdane",
    "Vural",
    "Vurgan",
    "Yabul",
    "Yaci",
    "Yadigaroğlu",
    "Yakar",
    "Yakişan",
    "Yakkan",
    "Yakut",
    "Yalinkiliç",
    "Yalniz",
    "Yalçin",
    "Yalçinkaya",
    "Yamak",
    "Yaman",
    "Yanardağ",
    "Yancar",
    "Yanik",
    "Yanmaz",
    "Yanni",
    "Yapar",
    "Yaprak",
    "Yaradilmiş",
    "Yarar",
    "Yarbil",
    "Yardimci",
    "Yasa",
    "Yavaşi",
    "Yavuz",
    "Yavuz Sezgin",
    "Yayikçi",
    "Yazak",
    "Yazici",
    "Yazici Erol",
    "Yağan",
    "Yağci",
    "Yağcizeybek",
    "Yağli",
    "Yaşan",
    "Yaşar",
    "Yaşit",
    "Yegen Yilmaz",
    "Yegin",
    "Yel",
    "Yeniay",
    "Yenidoğan",
    "Yenidünya",
    "Yenigün",
    "Yenilmez",
    "Yenin",
    "Yeniçeri",
    "Yeral",
    "Yerlikaya",
    "Yeter",
    "Yetiz",
    "Yetkinşekerci",
    "Yeşil",
    "Yeşildağer",
    "Yeşilfidan",
    "Yeşilkaya",
    "Yeşilova",
    "Yilanli",
    "Yildirim",
    "Yildirimçakar",
    "Yildiz",
    "Yildiz Altun",
    "Yildiz Bulut",
    "Yildizoğlu",
    "Yilmabaşar",
    "Yilmaz",
    "Yilmaz Gelebek",
    "Yilmaz inal",
    "Yilmaz Çiftdoğan",
    "Yiğit",
    "Yiğit Kuplay",
    "Yorganci",
    "Yumak",
    "Yumurtaş",
    "Yurdakök",
    "Yurdam",
    "Yurdseven",
    "Yurt",
    "Yurtdaş",
    "Yurtlu",
    "Yönet",
    "Yörük",
    "Yüce",
    "Yücel",
    "Yücetürk",
    "Yüksel",
    "Yükselmiş",
    "Yürek",
    "Yüzbaşioğlu",
    "Yüzer",
    "Zaim",
    "Zengin",
    "Zeybek",
    "Zeyli",
    "Zileligil",
    "Zorlu Karayiğit",
    "Zubaroğlu",
    "ibişoğlu",
    "ilbay",
    "ileri",
    "ilgen",
    "ilgün",
    "ilhan",
    "ilik",
    "ilkay",
    "ilker",
    "imali",
    "imamoğlu",
    "inan",
    "inanmaz",
    "inanç",
    "ince",
    "inceoğlu",
    "inci Kenar",
    "iner Köksal",
    "inselöz",
    "ipek",
    "iplikçi",
    "iris",
    "isen",
    "istek",
    "ivacik",
    "izci",
    "izgi",
    "içbay",
    "işgören",
    "iştar",
    "Çakir",
    "Çakmak",
    "Çalik",
    "Çalişkantürk",
    "Çamur",
    "Çangal",
    "Çankaya",
    "Çantay",
    "Çatak",
    "Çatuk",
    "Çavdar",
    "Çavli",
    "Çay",
    "Çayli",
    "Çağil",
    "Çağlar",
    "Çekiç",
    "Çelebi",
    "Çelen",
    "Çelik",
    "Çeliker",
    "Çelikten",
    "Çepni",
    "Çerik",
    "Çete",
    "Çetemen",
    "Çeter",
    "Çetin",
    "Çetiner",
    "Çetinkaya",
    "Çetinkor",
    "Çetintaş",
    "Çevik",
    "Çeviker",
    "Çevirgen",
    "Çeçen",
    "Çift",
    "Çiftci",
    "Çiftçi",
    "Çildir",
    "Çilesiz",
    "Çimen",
    "Çinar",
    "Çinarlik",
    "Çinkir",
    "Çinkit",
    "Çinpolat",
    "Çipe",
    "Çirakoğlu",
    "Çitil",
    "Çiçek",
    "Çiçekbilek",
    "Çoban",
    "Çobanoğlu",
    "Çobanyildizi",
    "Çoker",
    "Çolak",
    "Çolakerol",
    "Çomut",
    "Çopur",
    "Çöl",
    "Çölbe",
    "Çörekli",
    "Öcal",
    "Öcalan",
    "Öden",
    "Ökmen",
    "Öktem",
    "Ölker",
    "Önal",
    "Önal Musalar",
    "Öncel",
    "Önde",
    "Önder",
    "Önder Siviş",
    "Öner",
    "Öney Kurnaz",
    "Önvermez",
    "Ördek",
    "Ören",
    "Örenç",
    "Örnek",
    "Öter",
    "Öven Ustaalioğlu",
    "Öz",
    "Özalp",
    "Özan Sanhal",
    "Özanlağan",
    "Özaslan",
    "Özata",
    "Özateş",
    "Özavci Aygün",
    "Özaydin",
    "Özbek",
    "Özbey",
    "Özbeyler",
    "Özcan",
    "Özcanli",
    "Özcanoğlu",
    "Özdamar",
    "Özdemir",
    "Özdemir Akdur",
    "Özdemirkiran",
    "Özden",
    "Özdenoğlu",
    "Özdil",
    "Özdoğan",
    "Özdoğan Kavzoğlu",
    "Özek",
    "Özekli Misirlioğlu",
    "Özel",
    "Özen",
    "Özer",
    "Özer Çelik",
    "Özgüner",
    "Özgür",
    "Özgürol",
    "Özhan",
    "Öziş",
    "Özkan",
    "Özkanli",
    "Özkaya",
    "Özkaynar",
    "Özkiriş",
    "Özkurt",
    "Özkurt Pürcü",
    "Özlü",
    "Özmen",
    "Özmen Süner",
    "Özmuk",
    "Özsaygili",
    "Özsayim",
    "Özsoy",
    "Öztaş",
    "Öztoprak",
    "Öztürk",
    "Öztürkeri",
    "Özyörük",
    "Özçay",
    "Özçelik",
    "Özçelik Oral",
    "Özüak",
    "Özüdoğru",
    "Öğüt Aydin",
    "Öğütmen Koç",
    "Ülgen",
    "Ülger",
    "Ülkevan",
    "Ünal",
    "Ünalan",
    "Üngür",
    "Ünlü",
    "Ünsal",
    "Ünver",
    "Ünüvar",
    "Ünüş",
    "Üreyen",
    "Ürkmez",
    "Ürün",
    "Üstün",
    "Üstündağ",
    "Üzen",
    "Üzer",
    "Üzüm",
    "Üçer",
    "Üçgül",
    "Şahan",
    "Şahbaz",
    "Şahin",
    "Şahin Duyar",
    "Şahiner",
    "Şair",
    "Şanlier",
    "Şanlikan",
    "Şarlak",
    "Şatir Ertem",
    "Şatiroğlu",
    "Şaşmaz",
    "Şekerler",
    "Şeliman",
    "Şen",
    "Şen Gökçeimam",
    "Şen Tanrikulu",
    "Şencan",
    "Şener",
    "Şengül",
    "Şengüleroğlu",
    "Şentürk",
    "Şenöz",
    "Şerbetçi",
    "Şeyhanli",
    "Şimşek",
    "Şirin",
    "Şirzai",
]